# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.graph.defs
import chitose.app.bsky.richtext.facet
import typing

class List(chitose.Record):
    """"""

    def __init__(self, purpose: chitose.app.bsky.graph.defs.ListPurpose, name: str, created_at: str, description: typing.Optional[str]=None, description_facets: typing.Optional[list[chitose.app.bsky.richtext.facet.Facet]]=None, avatar: typing.Optional[chitose.Blob]=None) -> None:
        self.purpose = purpose
        self.name = name
        self.created_at = created_at
        self.description = description
        self.description_facets = description_facets
        self.avatar = avatar

    def to_dict(self) -> dict:
        return {'purpose': self.purpose, 'name': self.name, 'createdAt': self.created_at, 'description': self.description, 'descriptionFacets': self.description_facets, 'avatar': self.avatar, '$type': 'app.bsky.graph.list'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_moderation_reports(service: str, headers: dict[str, str], subject: typing.Optional[str]=None, resolved: typing.Optional[bool]=None, action_type: typing.Optional[typing.Literal['com.atproto.admin.defs#takedown', 'com.atproto.admin.defs#flag', 'com.atproto.admin.defs#acknowledge', 'com.atproto.admin.defs#escalate']]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """List moderation reports related to a subject."""
    return chitose.xrpc.call('com.atproto.admin.getModerationReports', [('subject', subject), ('resolved', resolved), ('actionType', action_type), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

class Label(chitose.Object):
    """


    :param src: DID of the actor who created this label

    :param uri: AT URI of the record, repository (account), or other resource which this label applies to

    :param val: the short string name of the value or type of this label

    :param cts: timestamp when this label was created

    :param cid: optionally, CID specifying the specific version of 'uri' resource this label applies to

    :param neg: if true, this is a negation label, overwriting a previous label
    """

    def __init__(self, src: str, uri: str, val: str, cts: str, cid: typing.Optional[str]=None, neg: typing.Optional[bool]=None) -> None:
        self.src = src
        self.uri = uri
        self.val = val
        self.cts = cts
        self.cid = cid
        self.neg = neg

    def to_dict(self) -> dict:
        return {'src': self.src, 'uri': self.uri, 'val': self.val, 'cts': self.cts, 'cid': self.cid, 'neg': self.neg, '$type': 'com.atproto.label.defs#label'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_invite_codes(service: str, headers: dict[str, str], sort: typing.Optional[typing.Literal['recent', 'usage']]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Admin view of invite codes"""
    return chitose.xrpc.call('com.atproto.admin.getInviteCodes', [('sort', sort), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.server.defs

class InviteCode(chitose.Object):
    """"""

    def __init__(self, code: str, available: int, disabled: bool, for_account: str, created_by: str, created_at: str, uses: list[chitose.com.atproto.server.defs.InviteCodeUse]) -> None:
        self.code = code
        self.available = available
        self.disabled = disabled
        self.for_account = for_account
        self.created_by = created_by
        self.created_at = created_at
        self.uses = uses

    def to_dict(self) -> dict:
        return {'code': self.code, 'available': self.available, 'disabled': self.disabled, 'forAccount': self.for_account, 'createdBy': self.created_by, 'createdAt': self.created_at, 'uses': self.uses, '$type': 'com.atproto.server.defs#inviteCode'}

class InviteCodeUse(chitose.Object):
    """"""

    def __init__(self, used_by: str, used_at: str) -> None:
        self.used_by = used_by
        self.used_at = used_at

    def to_dict(self) -> dict:
        return {'usedBy': self.used_by, 'usedAt': self.used_at, '$type': 'com.atproto.server.defs#inviteCodeUse'}


from . import Link


class Blob:
    def __init__(self, ref: Link, mime_type: str, size: int) -> None:
        self.ref = ref
        self.mime_type = mime_type
        self.size = size

    def to_dict(self) -> dict:
        return {
            '$type': 'blob',
            'ref': self.ref,
            'mimeType': self.mime_type,
            'size': self.size
        }



# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_repo(service: str, headers: dict[str, str], did: str, earliest: typing.Optional[str]=None, latest: typing.Optional[str]=None) -> bytes:
    """Gets the repo state.


    :param did: The DID of the repo.

    :param earliest: The earliest commit in the commit range (not inclusive)

    :param latest: The latest commit in the commit range (inclusive)
    """
    return chitose.xrpc.call('com.atproto.sync.getRepo', [('did', did), ('earliest', earliest), ('latest', latest)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _resolve_handle(service: str, headers: dict[str, str], handle: typing.Optional[str]=None) -> bytes:
    """Provides the DID of a repo.


    :param handle: The handle to resolve. If not supplied, will resolve the host's own handle.
    """
    return chitose.xrpc.call('com.atproto.identity.resolveHandle', [('handle', handle)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _request_password_reset(service: str, headers: dict[str, str], email: str) -> bytes:
    """Initiate a user account password reset via email."""
    return chitose.xrpc.call('com.atproto.server.requestPasswordReset', [], {'email': email}, service, {'Content-Type': 'application/json'} | headers)


from typing import Optional
from typing import Union
import json
import urllib.parse
import urllib.request


def call(method: str,
         params: list[tuple[str, Union[str, Optional[str],
                                       Optional[int], list[str]]]],
         d: Union[bytes, Optional[dict]], service: str, headers: dict[str, str]) -> bytes:
    url = f'{service}/xrpc/{method}'

    query: list[tuple[str, Union[str, int]]] = []
    for key, val in params:
        if val is None:
            continue

        if isinstance(val, list):
            query += [(key, v) for v in val]
            continue

        query.append((key, val))

    if query:
        url = f'{url}?{urllib.parse.urlencode(query)}'

    req = urllib.request.Request(url)
    for key, val in headers.items():
        req.add_header(key, val)

    if d:
        # for com.atproto.repo.uploadBlob
        if isinstance(d, bytes):
            data = d
        else:
            d = {
                key: val for key, val in d.items()
                if val is not None
            }
            data = json.dumps(d, default=lambda obj: {
                              key: val for key, val in obj.to_dict().items()
                              if val is not None
                              }).encode()
    else:
        data = None

    r = urllib.request.urlopen(req, data)
    return r.read()



# GENERATED CODE - DO NOT MODIFY
"""A representation of a record embedded in another form of content"""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import chitose.app.bsky.embed.external
import chitose.app.bsky.embed.images
import chitose.app.bsky.embed.record
import chitose.app.bsky.embed.record_with_media
import chitose.app.bsky.feed.defs
import chitose.com.atproto.label.defs
import chitose.com.atproto.repo.strong_ref
import typing

class Record(chitose.Object):
    """"""

    def __init__(self, record: chitose.com.atproto.repo.strong_ref.StrongRef) -> None:
        self.record = record

    def to_dict(self) -> dict:
        return {'record': self.record, '$type': 'app.bsky.embed.record'}

class View(chitose.Object):
    """"""

    def __init__(self, record: typing.Union[chitose.app.bsky.embed.record.ViewRecord, chitose.app.bsky.embed.record.ViewNotFound, chitose.app.bsky.embed.record.ViewBlocked, chitose.app.bsky.feed.defs.GeneratorView]) -> None:
        self.record = record

    def to_dict(self) -> dict:
        return {'record': self.record, '$type': 'app.bsky.embed.record#view'}

class ViewRecord(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, author: chitose.app.bsky.actor.defs.ProfileViewBasic, value: typing.Any, indexed_at: str, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None, embeds: typing.Optional[list[typing.Union[chitose.app.bsky.embed.images.View, chitose.app.bsky.embed.external.View, chitose.app.bsky.embed.record.View, chitose.app.bsky.embed.record_with_media.View]]]=None) -> None:
        self.uri = uri
        self.cid = cid
        self.author = author
        self.value = value
        self.indexed_at = indexed_at
        self.labels = labels
        self.embeds = embeds

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'author': self.author, 'value': self.value, 'indexedAt': self.indexed_at, 'labels': self.labels, 'embeds': self.embeds, '$type': 'app.bsky.embed.record#viewRecord'}

class ViewNotFound(chitose.Object):
    """"""

    def __init__(self, uri: str) -> None:
        self.uri = uri

    def to_dict(self) -> dict:
        return {'uri': self.uri, '$type': 'app.bsky.embed.record#viewNotFound'}

class ViewBlocked(chitose.Object):
    """"""

    def __init__(self, uri: str) -> None:
        self.uri = uri

    def to_dict(self) -> dict:
        return {'uri': self.uri, '$type': 'app.bsky.embed.record#viewBlocked'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .get_preferences import _get_preferences
from .get_profile import _get_profile
from .get_profiles import _get_profiles
from .get_suggestions import _get_suggestions
from .put_preferences import _put_preferences
from .search_actors import _search_actors
from .search_actors_typeahead import _search_actors_typeahead
import chitose.app.bsky.actor.defs
import typing

class Actor_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def search_actors_typeahead(self, term: typing.Optional[str]=None, limit: typing.Optional[int]=None) -> bytes:
        """Find actor suggestions for a search term."""
        return _search_actors_typeahead(self.service, self.headers, term, limit)

    def put_preferences(self, preferences: chitose.app.bsky.actor.defs.Preferences) -> bytes:
        """Sets the private preferences attached to the account."""
        return _put_preferences(self.service, self.headers, preferences)

    def get_profile(self, actor: str) -> bytes:
        """"""
        return _get_profile(self.service, self.headers, actor)

    def get_suggestions(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Get a list of actors suggested for following. Used in discovery UIs."""
        return _get_suggestions(self.service, self.headers, limit, cursor)

    def search_actors(self, term: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Find actors matching search criteria."""
        return _search_actors(self.service, self.headers, term, limit, cursor)

    def get_profiles(self, actors: list[str]) -> bytes:
        """"""
        return _get_profiles(self.service, self.headers, actors)

    def get_preferences(self) -> bytes:
        """Get private preferences attached to the account."""
        return _get_preferences(self.service, self.headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _update_handle(service: str, headers: dict[str, str], handle: str) -> bytes:
    """Updates the handle of the account"""
    return chitose.xrpc.call('com.atproto.identity.updateHandle', [], {'handle': handle}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import chitose.app.bsky.embed.external
import chitose.app.bsky.embed.images
import chitose.app.bsky.embed.record
import chitose.app.bsky.embed.record_with_media
import chitose.app.bsky.feed.defs
import chitose.app.bsky.richtext.facet
import chitose.com.atproto.label.defs
import typing

class PostView(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, author: chitose.app.bsky.actor.defs.ProfileViewBasic, record: typing.Any, indexed_at: str, embed: typing.Optional[typing.Union[chitose.app.bsky.embed.images.View, chitose.app.bsky.embed.external.View, chitose.app.bsky.embed.record.View, chitose.app.bsky.embed.record_with_media.View]]=None, reply_count: typing.Optional[int]=None, repost_count: typing.Optional[int]=None, like_count: typing.Optional[int]=None, viewer: typing.Optional[chitose.app.bsky.feed.defs.ViewerState]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.uri = uri
        self.cid = cid
        self.author = author
        self.record = record
        self.indexed_at = indexed_at
        self.embed = embed
        self.reply_count = reply_count
        self.repost_count = repost_count
        self.like_count = like_count
        self.viewer = viewer
        self.labels = labels

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'author': self.author, 'record': self.record, 'indexedAt': self.indexed_at, 'embed': self.embed, 'replyCount': self.reply_count, 'repostCount': self.repost_count, 'likeCount': self.like_count, 'viewer': self.viewer, 'labels': self.labels, '$type': 'app.bsky.feed.defs#postView'}

class ViewerState(chitose.Object):
    """"""

    def __init__(self, repost: typing.Optional[str]=None, like: typing.Optional[str]=None) -> None:
        self.repost = repost
        self.like = like

    def to_dict(self) -> dict:
        return {'repost': self.repost, 'like': self.like, '$type': 'app.bsky.feed.defs#viewerState'}

class FeedViewPost(chitose.Object):
    """"""

    def __init__(self, post: chitose.app.bsky.feed.defs.PostView, reply: typing.Optional[chitose.app.bsky.feed.defs.ReplyRef]=None, reason: typing.Optional[chitose.app.bsky.feed.defs.ReasonRepost]=None) -> None:
        self.post = post
        self.reply = reply
        self.reason = reason

    def to_dict(self) -> dict:
        return {'post': self.post, 'reply': self.reply, 'reason': self.reason, '$type': 'app.bsky.feed.defs#feedViewPost'}

class ReplyRef(chitose.Object):
    """"""

    def __init__(self, root: typing.Union[chitose.app.bsky.feed.defs.PostView, chitose.app.bsky.feed.defs.NotFoundPost, chitose.app.bsky.feed.defs.BlockedPost], parent: typing.Union[chitose.app.bsky.feed.defs.PostView, chitose.app.bsky.feed.defs.NotFoundPost, chitose.app.bsky.feed.defs.BlockedPost]) -> None:
        self.root = root
        self.parent = parent

    def to_dict(self) -> dict:
        return {'root': self.root, 'parent': self.parent, '$type': 'app.bsky.feed.defs#replyRef'}

class ReasonRepost(chitose.Object):
    """"""

    def __init__(self, by: chitose.app.bsky.actor.defs.ProfileViewBasic, indexed_at: str) -> None:
        self.by = by
        self.indexed_at = indexed_at

    def to_dict(self) -> dict:
        return {'by': self.by, 'indexedAt': self.indexed_at, '$type': 'app.bsky.feed.defs#reasonRepost'}

class ThreadViewPost(chitose.Object):
    """"""

    def __init__(self, post: chitose.app.bsky.feed.defs.PostView, parent: typing.Optional[typing.Union[chitose.app.bsky.feed.defs.ThreadViewPost, chitose.app.bsky.feed.defs.NotFoundPost, chitose.app.bsky.feed.defs.BlockedPost]]=None, replies: typing.Optional[list[typing.Union[chitose.app.bsky.feed.defs.ThreadViewPost, chitose.app.bsky.feed.defs.NotFoundPost, chitose.app.bsky.feed.defs.BlockedPost]]]=None) -> None:
        self.post = post
        self.parent = parent
        self.replies = replies

    def to_dict(self) -> dict:
        return {'post': self.post, 'parent': self.parent, 'replies': self.replies, '$type': 'app.bsky.feed.defs#threadViewPost'}

class NotFoundPost(chitose.Object):
    """"""

    def __init__(self, uri: str, not_found: bool) -> None:
        self.uri = uri
        self.not_found = not_found

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'notFound': self.not_found, '$type': 'app.bsky.feed.defs#notFoundPost'}

class BlockedPost(chitose.Object):
    """"""

    def __init__(self, uri: str, blocked: bool) -> None:
        self.uri = uri
        self.blocked = blocked

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'blocked': self.blocked, '$type': 'app.bsky.feed.defs#blockedPost'}

class GeneratorView(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, creator: chitose.app.bsky.actor.defs.ProfileView, display_name: str, indexed_at: str, did: typing.Optional[str]=None, description: typing.Optional[str]=None, description_facets: typing.Optional[list[chitose.app.bsky.richtext.facet.Facet]]=None, avatar: typing.Optional[str]=None, like_count: typing.Optional[int]=None, viewer: typing.Optional[chitose.app.bsky.feed.defs.GeneratorViewerState]=None) -> None:
        self.uri = uri
        self.cid = cid
        self.creator = creator
        self.display_name = display_name
        self.indexed_at = indexed_at
        self.did = did
        self.description = description
        self.description_facets = description_facets
        self.avatar = avatar
        self.like_count = like_count
        self.viewer = viewer

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'creator': self.creator, 'displayName': self.display_name, 'indexedAt': self.indexed_at, 'did': self.did, 'description': self.description, 'descriptionFacets': self.description_facets, 'avatar': self.avatar, 'likeCount': self.like_count, 'viewer': self.viewer, '$type': 'app.bsky.feed.defs#generatorView'}

class GeneratorViewerState(chitose.Object):
    """"""

    def __init__(self, like: typing.Optional[str]=None) -> None:
        self.like = like

    def to_dict(self) -> dict:
        return {'like': self.like, '$type': 'app.bsky.feed.defs#generatorViewerState'}

class SkeletonFeedPost(chitose.Object):
    """"""

    def __init__(self, post: str, reason: typing.Optional[chitose.app.bsky.feed.defs.SkeletonReasonRepost]=None) -> None:
        self.post = post
        self.reason = reason

    def to_dict(self) -> dict:
        return {'post': self.post, 'reason': self.reason, '$type': 'app.bsky.feed.defs#skeletonFeedPost'}

class SkeletonReasonRepost(chitose.Object):
    """"""

    def __init__(self, repost: str) -> None:
        self.repost = repost

    def to_dict(self) -> dict:
        return {'repost': self.repost, '$type': 'app.bsky.feed.defs#skeletonReasonRepost'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .atproto import Atproto_

class Com_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    @property
    def atproto(self):
        return Atproto_(self.service, self.headers)


# GENERATED CODE - DO NOT MODIFY
"""A URI with a content-hash fingerprint."""
from __future__ import annotations
import chitose

class StrongRef(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str) -> None:
        self.uri = uri
        self.cid = cid

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, '$type': 'com.atproto.repo.strongRef'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .get_popular import _get_popular
import typing

class Unspecced_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def get_popular(self, include_nsfw: typing.Optional[bool]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """An unspecced view of globally popular items"""
        return _get_popular(self.service, self.headers, include_nsfw, limit, cursor)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_profiles(service: str, headers: dict[str, str], actors: list[str]) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.actor.getProfiles', [('actors', actors)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .create_account import _create_account
from .create_app_password import _create_app_password
from .create_invite_code import _create_invite_code
from .create_invite_codes import _create_invite_codes
from .create_session import _create_session
from .delete_account import _delete_account
from .delete_session import _delete_session
from .describe_server import _describe_server
from .get_account_invite_codes import _get_account_invite_codes
from .get_session import _get_session
from .list_app_passwords import _list_app_passwords
from .refresh_session import _refresh_session
from .request_account_delete import _request_account_delete
from .request_password_reset import _request_password_reset
from .reset_password import _reset_password
from .revoke_app_password import _revoke_app_password
import typing

class Server_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def get_account_invite_codes(self, include_used: typing.Optional[bool]=None, create_available: typing.Optional[bool]=None) -> bytes:
        """Get all invite codes for a given account"""
        return _get_account_invite_codes(self.service, self.headers, include_used, create_available)

    def create_session(self, identifier: str, password: str) -> bytes:
        """Create an authentication session.


        :param identifier: Handle or other identifier supported by the server for the authenticating user.
        """
        return _create_session(self.service, self.headers, identifier, password)

    def list_app_passwords(self) -> bytes:
        """List all app-specific passwords."""
        return _list_app_passwords(self.service, self.headers)

    def create_invite_codes(self, code_count: int, use_count: int, for_accounts: typing.Optional[list[str]]=None) -> bytes:
        """Create an invite code."""
        return _create_invite_codes(self.service, self.headers, code_count, use_count, for_accounts)

    def delete_session(self) -> bytes:
        """Delete the current session."""
        return _delete_session(self.service, self.headers)

    def revoke_app_password(self, name: str) -> bytes:
        """Revoke an app-specific password by name."""
        return _revoke_app_password(self.service, self.headers, name)

    def create_app_password(self, name: str) -> bytes:
        """Create an app-specific password."""
        return _create_app_password(self.service, self.headers, name)

    def describe_server(self) -> bytes:
        """Get a document describing the service's accounts configuration."""
        return _describe_server(self.service, self.headers)

    def get_session(self) -> bytes:
        """Get information about the current session."""
        return _get_session(self.service, self.headers)

    def refresh_session(self) -> bytes:
        """Refresh an authentication session."""
        return _refresh_session(self.service, self.headers)

    def reset_password(self, token: str, password: str) -> bytes:
        """Reset a user account password using a token."""
        return _reset_password(self.service, self.headers, token, password)

    def request_password_reset(self, email: str) -> bytes:
        """Initiate a user account password reset via email."""
        return _request_password_reset(self.service, self.headers, email)

    def request_account_delete(self) -> bytes:
        """Initiate a user account deletion via email."""
        return _request_account_delete(self.service, self.headers)

    def create_account(self, email: str, handle: str, password: str, did: typing.Optional[str]=None, invite_code: typing.Optional[str]=None, recovery_key: typing.Optional[str]=None) -> bytes:
        """Create an account."""
        return _create_account(self.service, self.headers, email, handle, password, did, invite_code, recovery_key)

    def delete_account(self, did: str, password: str, token: str) -> bytes:
        """Delete a user account with a token and password."""
        return _delete_account(self.service, self.headers, did, password, token)

    def create_invite_code(self, use_count: int, for_account: typing.Optional[str]=None) -> bytes:
        """Create an invite code."""
        return _create_invite_code(self.service, self.headers, use_count, for_account)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _request_account_delete(service: str, headers: dict[str, str]) -> bytes:
    """Initiate a user account deletion via email."""
    return chitose.xrpc.call('com.atproto.server.requestAccountDelete', [], {}, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_blob(service: str, headers: dict[str, str], did: str, cid: str) -> bytes:
    """Get a blob associated with a given repo.


    :param did: The DID of the repo.

    :param cid: The CID of the blob to fetch
    """
    return chitose.xrpc.call('com.atproto.sync.getBlob', [('did', did), ('cid', cid)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_post_thread(service: str, headers: dict[str, str], uri: str, depth: typing.Optional[int]=None) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.feed.getPostThread', [('uri', uri), ('depth', depth)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _create_app_password(service: str, headers: dict[str, str], name: str) -> bytes:
    """Create an app-specific password."""
    return chitose.xrpc.call('com.atproto.server.createAppPassword', [], {'name': name}, service, {'Content-Type': 'application/json'} | headers)

class AppPassword(chitose.Object):
    """"""

    def __init__(self, name: str, password: str, created_at: str) -> None:
        self.name = name
        self.password = password
        self.created_at = created_at

    def to_dict(self) -> dict:
        return {'name': self.name, 'password': self.password, 'createdAt': self.created_at, '$type': 'com.atproto.server.createAppPassword#appPassword'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_unread_count(service: str, headers: dict[str, str], seen_at: typing.Optional[str]=None) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.notification.getUnreadCount', [('seenAt', seen_at)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_moderation_report(service: str, headers: dict[str, str], id: int) -> bytes:
    """View details about a moderation report."""
    return chitose.xrpc.call('com.atproto.admin.getModerationReport', [('id', id)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _reset_password(service: str, headers: dict[str, str], token: str, password: str) -> bytes:
    """Reset a user account password using a token."""
    return chitose.xrpc.call('com.atproto.server.resetPassword', [], {'token': token, 'password': password}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _create_account(service: str, headers: dict[str, str], email: str, handle: str, password: str, did: typing.Optional[str]=None, invite_code: typing.Optional[str]=None, recovery_key: typing.Optional[str]=None) -> bytes:
    """Create an account."""
    return chitose.xrpc.call('com.atproto.server.createAccount', [], {'email': email, 'handle': handle, 'did': did, 'inviteCode': invite_code, 'password': password, 'recoveryKey': recovery_key}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import chitose.com.atproto.label.defs
import typing

def _list_notifications(service: str, headers: dict[str, str], limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None, seen_at: typing.Optional[str]=None) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.notification.listNotifications', [('limit', limit), ('cursor', cursor), ('seenAt', seen_at)], None, service, {} | headers)

class Notification(chitose.Object):
    """


    :param reason: Expected values are 'like', 'repost', 'follow', 'mention', 'reply', and 'quote'.
    """

    def __init__(self, uri: str, cid: str, author: chitose.app.bsky.actor.defs.ProfileView, reason: typing.Literal['like', 'repost', 'follow', 'mention', 'reply', 'quote'], record: typing.Any, is_read: bool, indexed_at: str, reason_subject: typing.Optional[str]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.uri = uri
        self.cid = cid
        self.author = author
        self.reason = reason
        self.record = record
        self.is_read = is_read
        self.indexed_at = indexed_at
        self.reason_subject = reason_subject
        self.labels = labels

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'author': self.author, 'reason': self.reason, 'record': self.record, 'isRead': self.is_read, 'indexedAt': self.indexed_at, 'reasonSubject': self.reason_subject, 'labels': self.labels, '$type': 'app.bsky.notification.listNotifications#notification'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_profile(service: str, headers: dict[str, str], actor: str) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.actor.getProfile', [('actor', actor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .actor import Actor_
from .embed import Embed_
from .feed import Feed_
from .graph import Graph_
from .notification import Notification_
from .richtext import Richtext_
from .unspecced import Unspecced_

class Bsky_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    @property
    def actor(self):
        return Actor_(self.service, self.headers)

    @property
    def embed(self):
        return Embed_(self.service, self.headers)

    @property
    def feed(self):
        return Feed_(self.service, self.headers)

    @property
    def graph(self):
        return Graph_(self.service, self.headers)

    @property
    def notification(self):
        return Notification_(self.service, self.headers)

    @property
    def richtext(self):
        return Richtext_(self.service, self.headers)

    @property
    def unspecced(self):
        return Unspecced_(self.service, self.headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_record(service: str, headers: dict[str, str], uri: str, cid: typing.Optional[str]=None) -> bytes:
    """View details about a record."""
    return chitose.xrpc.call('com.atproto.admin.getRecord', [('uri', uri), ('cid', cid)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_feed_generators(service: str, headers: dict[str, str], feeds: list[str]) -> bytes:
    """Get information about a list of feed generators"""
    return chitose.xrpc.call('app.bsky.feed.getFeedGenerators', [('feeds', feeds)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.label.defs
import typing

class Labels(chitose.Object):
    """"""

    def __init__(self, seq: int, labels: list[chitose.com.atproto.label.defs.Label]) -> None:
        self.seq = seq
        self.labels = labels

    def to_dict(self) -> dict:
        return {'seq': self.seq, 'labels': self.labels, '$type': 'com.atproto.label.subscribeLabels#labels'}

class Info(chitose.Object):
    """"""

    def __init__(self, name: typing.Literal['OutdatedCursor',], message: typing.Optional[str]=None) -> None:
        self.name = name
        self.message = message

    def to_dict(self) -> dict:
        return {'name': self.name, 'message': self.message, '$type': 'com.atproto.label.subscribeLabels#info'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

class Block(chitose.Record):
    """"""

    def __init__(self, subject: str, created_at: str) -> None:
        self.subject = subject
        self.created_at = created_at

    def to_dict(self) -> dict:
        return {'subject': self.subject, 'createdAt': self.created_at, '$type': 'app.bsky.graph.block'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _mute_actor_list(service: str, headers: dict[str, str], list: str) -> bytes:
    """Mute a list of actors."""
    return chitose.xrpc.call('app.bsky.graph.muteActorList', [], {'list': list}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.admin.defs
import chitose.com.atproto.repo.strong_ref
import typing

def _take_moderation_action(service: str, headers: dict[str, str], action: typing.Literal['com.atproto.admin.defs#takedown', 'com.atproto.admin.defs#flag', 'com.atproto.admin.defs#acknowledge'], subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], reason: str, created_by: str, subject_blob_cids: typing.Optional[list[str]]=None, create_label_vals: typing.Optional[list[str]]=None, negate_label_vals: typing.Optional[list[str]]=None) -> bytes:
    """Take a moderation action on a repo."""
    return chitose.xrpc.call('com.atproto.admin.takeModerationAction', [], {'action': action, 'subject': subject, 'subjectBlobCids': subject_blob_cids, 'createLabelVals': create_label_vals, 'negateLabelVals': negate_label_vals, 'reason': reason, 'createdBy': created_by}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
"""A representation of some externally linked content, embedded in another form of content"""
from __future__ import annotations
import chitose
import chitose.app.bsky.embed.external
import typing

class External(chitose.Object):
    """"""

    def __init__(self, external: chitose.app.bsky.embed.external.ExternalExternal) -> None:
        self.external = external

    def to_dict(self) -> dict:
        return {'external': self.external, '$type': 'app.bsky.embed.external'}

class ExternalExternal(chitose.Object):
    """"""

    def __init__(self, uri: str, title: str, description: str, thumb: typing.Optional[chitose.Blob]=None) -> None:
        self.uri = uri
        self.title = title
        self.description = description
        self.thumb = thumb

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'title': self.title, 'description': self.description, 'thumb': self.thumb, '$type': 'app.bsky.embed.external#external'}

class View(chitose.Object):
    """"""

    def __init__(self, external: chitose.app.bsky.embed.external.ViewExternal) -> None:
        self.external = external

    def to_dict(self) -> dict:
        return {'external': self.external, '$type': 'app.bsky.embed.external#view'}

class ViewExternal(chitose.Object):
    """"""

    def __init__(self, uri: str, title: str, description: str, thumb: typing.Optional[str]=None) -> None:
        self.uri = uri
        self.title = title
        self.description = description
        self.thumb = thumb

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'title': self.title, 'description': self.description, 'thumb': self.thumb, '$type': 'app.bsky.embed.external#viewExternal'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .get_blocks import _get_blocks
from .get_followers import _get_followers
from .get_follows import _get_follows
from .get_list import _get_list
from .get_list_mutes import _get_list_mutes
from .get_lists import _get_lists
from .get_mutes import _get_mutes
from .mute_actor import _mute_actor
from .mute_actor_list import _mute_actor_list
from .unmute_actor import _unmute_actor
from .unmute_actor_list import _unmute_actor_list
import typing

class Graph_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def unmute_actor_list(self, list: str) -> bytes:
        """Unmute a list of actors."""
        return _unmute_actor_list(self.service, self.headers, list)

    def mute_actor_list(self, list: str) -> bytes:
        """Mute a list of actors."""
        return _mute_actor_list(self.service, self.headers, list)

    def get_lists(self, actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Fetch a list of lists that belong to an actor"""
        return _get_lists(self.service, self.headers, actor, limit, cursor)

    def get_followers(self, actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Who is following an actor?"""
        return _get_followers(self.service, self.headers, actor, limit, cursor)

    def mute_actor(self, actor: str) -> bytes:
        """Mute an actor by did or handle."""
        return _mute_actor(self.service, self.headers, actor)

    def get_mutes(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Who does the viewer mute?"""
        return _get_mutes(self.service, self.headers, limit, cursor)

    def get_list_mutes(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Which lists is the requester's account muting?"""
        return _get_list_mutes(self.service, self.headers, limit, cursor)

    def get_follows(self, actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Who is an actor following?"""
        return _get_follows(self.service, self.headers, actor, limit, cursor)

    def get_blocks(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Who is the requester's account blocking?"""
        return _get_blocks(self.service, self.headers, limit, cursor)

    def unmute_actor(self, actor: str) -> bytes:
        """Unmute an actor by did or handle."""
        return _unmute_actor(self.service, self.headers, actor)

    def get_list(self, list: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Fetch a list of actors"""
        return _get_list(self.service, self.headers, list, limit, cursor)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .create_report import _create_report
import chitose.com.atproto.admin.defs
import chitose.com.atproto.moderation.defs
import chitose.com.atproto.repo.strong_ref
import typing

class Moderation_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def create_report(self, reason_type: chitose.com.atproto.moderation.defs.ReasonType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], reason: typing.Optional[str]=None) -> bytes:
        """Report a repo or a record."""
        return _create_report(self.service, self.headers, reason_type, subject, reason)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _unmute_actor(service: str, headers: dict[str, str], actor: str) -> bytes:
    """Unmute an actor by did or handle."""
    return chitose.xrpc.call('app.bsky.graph.unmuteActor', [], {'actor': actor}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _list_records(service: str, headers: dict[str, str], repo: str, collection: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None, rkey_start: typing.Optional[str]=None, rkey_end: typing.Optional[str]=None, reverse: typing.Optional[bool]=None) -> bytes:
    """List a range of records in a collection.


    :param repo: The handle or DID of the repo.

    :param collection: The NSID of the record type.

    :param limit: The number of records to return.

    :param rkey_start: DEPRECATED: The lowest sort-ordered rkey to start from (exclusive)

    :param rkey_end: DEPRECATED: The highest sort-ordered rkey to stop at (exclusive)

    :param reverse: Reverse the order of the returned records?
    """
    return chitose.xrpc.call('com.atproto.repo.listRecords', [('repo', repo), ('collection', collection), ('limit', limit), ('cursor', cursor), ('rkeyStart', rkey_start), ('rkeyEnd', rkey_end), ('reverse', reverse)], None, service, {} | headers)

class Record(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, value: typing.Any) -> None:
        self.uri = uri
        self.cid = cid
        self.value = value

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'value': self.value, '$type': 'com.atproto.repo.listRecords#record'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _update_account_handle(service: str, headers: dict[str, str], did: str, handle: str) -> bytes:
    """Administrative action to update an account's handle"""
    return chitose.xrpc.call('com.atproto.admin.updateAccountHandle', [], {'did': did, 'handle': handle}, service, {'Content-Type': 'application/json'} | headers)


from __future__ import annotations
from datetime import datetime
from datetime import timezone
import typing
import json

from chitose.app.bsky.feed.like import Like
from chitose.app.bsky.feed.post import Post
from chitose.app.bsky.feed.repost import Repost
from chitose.app.bsky.graph.follow import Follow
from chitose.com.atproto.repo.strong_ref import StrongRef

from .app import App_
from .com import Com_


class BskyAgent:
    def __init__(self, service: str) -> None:
        self.service = service
        self.headers: dict[str, str] = {}
        self.session: dict = {}

    @property
    def app(self):
        return App_(self.service, self.headers)

    @property
    def com(self):
        return Com_(self.service, self.headers)

    def get_timeline(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_timeline(**kwargs)

    def get_author_feed(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_author_feed(**kwargs)

    def get_post_thread(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_post_thread(**kwargs)

    def get_posts(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_posts(**kwargs)

    def get_likes(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_likes(**kwargs)

    def get_reposted_by(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.feed` for available arguments."""
        return self.app.bsky.feed.get_reposted_by(**kwargs)

    def get_follows(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.graph` for available arguments."""
        return self.app.bsky.graph.get_follows(**kwargs)

    def get_followers(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.graph` for available arguments."""
        return self.app.bsky.graph.get_followers(**kwargs)

    def get_profile(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.actor` for available arguments."""
        return self.app.bsky.actor.get_profile(**kwargs)

    def get_profiles(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.actor` for available arguments."""
        return self.app.bsky.actor.get_profiles(**kwargs)

    def get_suggestions(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.actor` for available arguments."""
        return self.app.bsky.actor.get_suggestions(**kwargs)

    def search_actors(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.actor` for available arguments."""
        return self.app.bsky.actor.search_actors(**kwargs)

    def search_actors_typeahead(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.actor` for available arguments."""
        return self.app.bsky.actor.search_actors_typeahead(**kwargs)

    def list_notifications(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See :doc:`chitose.app.bsky.notification` for available arguments."""
        return self.app.bsky.notification.list_notifications(**kwargs)

    def count_unread_notifications(self, **kwargs: dict[str, typing.Any]) -> bytes:
        """See `get_unread_count()` in :doc:`chitose.app.bsky.notification` for available arguments."""
        return self.app.bsky.notification.get_unread_count(**kwargs)

    def post(self, record: Post) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        return self.com.atproto.repo.create_record(
            repo=self.session['did'],
            collection='app.bsky.feed.post',
            record=record)

    def _get_did_and_rkey(self, uri: str) -> tuple[str, str]:
        did_name_path = uri.partition('?')[0].partition('//')[2].split('/')
        if len(did_name_path) != 3:
            raise Exception(f'Invalid at uri: {uri}')

        did, _, rkey = did_name_path
        return did, rkey

    def delete_post(self, post_uri: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        did, rkey = self._get_did_and_rkey(post_uri)
        return self.com.atproto.repo.delete_record(
            repo=did,
            collection='app.bsky.feed.post',
            rkey=rkey)

    def like(self, uri: str, cid: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        subject = StrongRef(uri=uri, cid=cid)
        record = Like(subject=subject,
                      created_at=datetime.now(timezone.utc).isoformat())

        return self.com.atproto.repo.create_record(
            repo=self.session['did'],
            collection='app.bsky.feed.like',
            record=record)

    def delete_like(self, like_uri: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        did, rkey = self._get_did_and_rkey(like_uri)
        return self.com.atproto.repo.delete_record(
            repo=did,
            collection='app.bsky.feed.like',
            rkey=rkey)

    def repost(self, uri: str, cid: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        subject = StrongRef(uri=uri, cid=cid)
        record = Repost(subject=subject,
                        created_at=datetime.now(timezone.utc).isoformat())

        return self.com.atproto.repo.create_record(
            repo=self.session['did'],
            collection='app.bsky.feed.repost',
            record=record)

    def delete_repost(self, repost_uri: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        did, rkey = self._get_did_and_rkey(repost_uri)
        return self.com.atproto.repo.delete_record(
            repo=did,
            collection='app.bsky.feed.repost',
            rkey=rkey)

    def follow(self, subject_did: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        record = Follow(subject=subject_did,
                        created_at=datetime.now(timezone.utc).isoformat())

        return self.com.atproto.repo.create_record(
            repo=self.session['did'],
            collection='app.bsky.graph.follow',
            record=record)

    def delete_follow(self, follow_uri: str) -> bytes:
        if not self.session:
            raise Exception('Not logged in')

        did, rkey = self._get_did_and_rkey(follow_uri)
        return self.com.atproto.repo.delete_record(
            repo=did,
            collection='app.bsky.graph.follow',
            rkey=rkey)

    def mute_actor(self, actor: str) -> bytes:
        return self.app.bsky.graph.mute_actor(actor=actor)

    def unmute_actor(self, actor: str) -> bytes:
        return self.app.bsky.graph.unmute_actor(actor=actor)

    def update_seen_notifications(self, seen_at: typing.Optional[str]) -> bytes:
        if seen_at is None:
            seen_at = datetime.now(timezone.utc).isoformat()

        return self.app.bsky.notification.update_seen(seen_at=seen_at)

    def login(self, identifier: str, password: str) -> None:
        self.session = json.loads(
            self.com.atproto.server.create_session(
                identifier=identifier, password=password))

        if 'accessJwt' in self.session:
            self.headers['authorization'] \
                = f'Bearer {self.session["accessJwt"]}'



# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.sync.subscribe_repos
import typing

class Commit(chitose.Object):
    """


    :param blocks: CAR file containing relevant blocks
    """

    def __init__(self, seq: int, rebase: bool, too_big: bool, repo: str, commit: typing.Any, prev: typing.Any, blocks: typing.Any, ops: list[chitose.com.atproto.sync.subscribe_repos.RepoOp], blobs: list[typing.Any], time: str) -> None:
        self.seq = seq
        self.rebase = rebase
        self.too_big = too_big
        self.repo = repo
        self.commit = commit
        self.prev = prev
        self.blocks = blocks
        self.ops = ops
        self.blobs = blobs
        self.time = time

    def to_dict(self) -> dict:
        return {'seq': self.seq, 'rebase': self.rebase, 'tooBig': self.too_big, 'repo': self.repo, 'commit': self.commit, 'prev': self.prev, 'blocks': self.blocks, 'ops': self.ops, 'blobs': self.blobs, 'time': self.time, '$type': 'com.atproto.sync.subscribeRepos#commit'}

class Handle(chitose.Object):
    """"""

    def __init__(self, seq: int, did: str, handle: str, time: str) -> None:
        self.seq = seq
        self.did = did
        self.handle = handle
        self.time = time

    def to_dict(self) -> dict:
        return {'seq': self.seq, 'did': self.did, 'handle': self.handle, 'time': self.time, '$type': 'com.atproto.sync.subscribeRepos#handle'}

class Migrate(chitose.Object):
    """"""

    def __init__(self, seq: int, did: str, migrate_to: str, time: str) -> None:
        self.seq = seq
        self.did = did
        self.migrate_to = migrate_to
        self.time = time

    def to_dict(self) -> dict:
        return {'seq': self.seq, 'did': self.did, 'migrateTo': self.migrate_to, 'time': self.time, '$type': 'com.atproto.sync.subscribeRepos#migrate'}

class Tombstone(chitose.Object):
    """"""

    def __init__(self, seq: int, did: str, time: str) -> None:
        self.seq = seq
        self.did = did
        self.time = time

    def to_dict(self) -> dict:
        return {'seq': self.seq, 'did': self.did, 'time': self.time, '$type': 'com.atproto.sync.subscribeRepos#tombstone'}

class Info(chitose.Object):
    """"""

    def __init__(self, name: typing.Literal['OutdatedCursor',], message: typing.Optional[str]=None) -> None:
        self.name = name
        self.message = message

    def to_dict(self) -> dict:
        return {'name': self.name, 'message': self.message, '$type': 'com.atproto.sync.subscribeRepos#info'}

class RepoOp(chitose.Object):
    """"""

    def __init__(self, action: typing.Literal['create', 'update', 'delete'], path: str, cid: typing.Any) -> None:
        self.action = action
        self.path = path
        self.cid = cid

    def to_dict(self) -> dict:
        return {'action': self.action, 'path': self.path, 'cid': self.cid, '$type': 'com.atproto.sync.subscribeRepos#repoOp'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .query_labels import _query_labels
import typing

class Label_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def query_labels(self, uri_patterns: list[str], sources: typing.Optional[list[str]]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Find labels relevant to the provided URI patterns.


        :param uri_patterns: List of AT URI patterns to match (boolean 'OR'). Each may be a prefix (ending with '*'; will match inclusive of the string leading to '*'), or a full URI

        :param sources: Optional list of label sources (DIDs) to filter on
        """
        return _query_labels(self.service, self.headers, uri_patterns, sources, limit, cursor)


# GENERATED CODE - DO NOT MODIFY
"""A reference to an actor in the network."""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import chitose.app.bsky.graph.defs
import chitose.com.atproto.label.defs
import typing

class ProfileViewBasic(chitose.Object):
    """"""

    def __init__(self, did: str, handle: str, display_name: typing.Optional[str]=None, avatar: typing.Optional[str]=None, viewer: typing.Optional[chitose.app.bsky.actor.defs.ViewerState]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.did = did
        self.handle = handle
        self.display_name = display_name
        self.avatar = avatar
        self.viewer = viewer
        self.labels = labels

    def to_dict(self) -> dict:
        return {'did': self.did, 'handle': self.handle, 'displayName': self.display_name, 'avatar': self.avatar, 'viewer': self.viewer, 'labels': self.labels, '$type': 'app.bsky.actor.defs#profileViewBasic'}

class ProfileView(chitose.Object):
    """"""

    def __init__(self, did: str, handle: str, display_name: typing.Optional[str]=None, description: typing.Optional[str]=None, avatar: typing.Optional[str]=None, indexed_at: typing.Optional[str]=None, viewer: typing.Optional[chitose.app.bsky.actor.defs.ViewerState]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.did = did
        self.handle = handle
        self.display_name = display_name
        self.description = description
        self.avatar = avatar
        self.indexed_at = indexed_at
        self.viewer = viewer
        self.labels = labels

    def to_dict(self) -> dict:
        return {'did': self.did, 'handle': self.handle, 'displayName': self.display_name, 'description': self.description, 'avatar': self.avatar, 'indexedAt': self.indexed_at, 'viewer': self.viewer, 'labels': self.labels, '$type': 'app.bsky.actor.defs#profileView'}

class ProfileViewDetailed(chitose.Object):
    """"""

    def __init__(self, did: str, handle: str, display_name: typing.Optional[str]=None, description: typing.Optional[str]=None, avatar: typing.Optional[str]=None, banner: typing.Optional[str]=None, followers_count: typing.Optional[int]=None, follows_count: typing.Optional[int]=None, posts_count: typing.Optional[int]=None, indexed_at: typing.Optional[str]=None, viewer: typing.Optional[chitose.app.bsky.actor.defs.ViewerState]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.did = did
        self.handle = handle
        self.display_name = display_name
        self.description = description
        self.avatar = avatar
        self.banner = banner
        self.followers_count = followers_count
        self.follows_count = follows_count
        self.posts_count = posts_count
        self.indexed_at = indexed_at
        self.viewer = viewer
        self.labels = labels

    def to_dict(self) -> dict:
        return {'did': self.did, 'handle': self.handle, 'displayName': self.display_name, 'description': self.description, 'avatar': self.avatar, 'banner': self.banner, 'followersCount': self.followers_count, 'followsCount': self.follows_count, 'postsCount': self.posts_count, 'indexedAt': self.indexed_at, 'viewer': self.viewer, 'labels': self.labels, '$type': 'app.bsky.actor.defs#profileViewDetailed'}

class ViewerState(chitose.Object):
    """"""

    def __init__(self, muted: typing.Optional[bool]=None, muted_by_list: typing.Optional[chitose.app.bsky.graph.defs.ListViewBasic]=None, blocked_by: typing.Optional[bool]=None, blocking: typing.Optional[str]=None, following: typing.Optional[str]=None, followed_by: typing.Optional[str]=None) -> None:
        self.muted = muted
        self.muted_by_list = muted_by_list
        self.blocked_by = blocked_by
        self.blocking = blocking
        self.following = following
        self.followed_by = followed_by

    def to_dict(self) -> dict:
        return {'muted': self.muted, 'mutedByList': self.muted_by_list, 'blockedBy': self.blocked_by, 'blocking': self.blocking, 'following': self.following, 'followedBy': self.followed_by, '$type': 'app.bsky.actor.defs#viewerState'}
Preferences = list[typing.Union['chitose.app.bsky.actor.defs.AdultContentPref', 'chitose.app.bsky.actor.defs.ContentLabelPref', 'chitose.app.bsky.actor.defs.SavedFeedsPref']]

class AdultContentPref(chitose.Object):
    """"""

    def __init__(self, enabled: bool) -> None:
        self.enabled = enabled

    def to_dict(self) -> dict:
        return {'enabled': self.enabled, '$type': 'app.bsky.actor.defs#adultContentPref'}

class ContentLabelPref(chitose.Object):
    """"""

    def __init__(self, label: str, visibility: typing.Literal['show', 'warn', 'hide']) -> None:
        self.label = label
        self.visibility = visibility

    def to_dict(self) -> dict:
        return {'label': self.label, 'visibility': self.visibility, '$type': 'app.bsky.actor.defs#contentLabelPref'}

class SavedFeedsPref(chitose.Object):
    """"""

    def __init__(self, pinned: list[str], saved: list[str]) -> None:
        self.pinned = pinned
        self.saved = saved

    def to_dict(self) -> dict:
        return {'pinned': self.pinned, 'saved': self.saved, '$type': 'app.bsky.actor.defs#savedFeedsPref'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _reverse_moderation_action(service: str, headers: dict[str, str], id: int, reason: str, created_by: str) -> bytes:
    """Reverse a moderation action."""
    return chitose.xrpc.call('com.atproto.admin.reverseModerationAction', [], {'id': id, 'reason': reason, 'createdBy': created_by}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_popular(service: str, headers: dict[str, str], include_nsfw: typing.Optional[bool]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """An unspecced view of globally popular items"""
    return chitose.xrpc.call('app.bsky.unspecced.getPopular', [('includeNsfw', include_nsfw), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .resolve_handle import _resolve_handle
from .update_handle import _update_handle
import typing

class Identity_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def update_handle(self, handle: str) -> bytes:
        """Updates the handle of the account"""
        return _update_handle(self.service, self.headers, handle)

    def resolve_handle(self, handle: typing.Optional[str]=None) -> bytes:
        """Provides the DID of a repo.


        :param handle: The handle to resolve. If not supplied, will resolve the host's own handle.
        """
        return _resolve_handle(self.service, self.headers, handle)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_repo(service: str, headers: dict[str, str], did: str) -> bytes:
    """View details about a repository."""
    return chitose.xrpc.call('com.atproto.admin.getRepo', [('did', did)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .admin import Admin_
from .identity import Identity_
from .label import Label_
from .moderation import Moderation_
from .repo import Repo_
from .server import Server_
from .sync import Sync_

class Atproto_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    @property
    def admin(self):
        return Admin_(self.service, self.headers)

    @property
    def identity(self):
        return Identity_(self.service, self.headers)

    @property
    def label(self):
        return Label_(self.service, self.headers)

    @property
    def moderation(self):
        return Moderation_(self.service, self.headers)

    @property
    def repo(self):
        return Repo_(self.service, self.headers)

    @property
    def server(self):
        return Server_(self.service, self.headers)

    @property
    def sync(self):
        return Sync_(self.service, self.headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_feed(service: str, headers: dict[str, str], feed: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Compose and hydrate a feed from a user's selected feed generator"""
    return chitose.xrpc.call('app.bsky.feed.getFeed', [('feed', feed), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_record(service: str, headers: dict[str, str], repo: str, collection: str, rkey: str, cid: typing.Optional[str]=None) -> bytes:
    """Get a record.


    :param repo: The handle or DID of the repo.

    :param collection: The NSID of the record collection.

    :param rkey: The key of the record.

    :param cid: The CID of the version of the record. If not specified, then return the most recent version.
    """
    return chitose.xrpc.call('com.atproto.repo.getRecord', [('repo', repo), ('collection', collection), ('rkey', rkey), ('cid', cid)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_session(service: str, headers: dict[str, str]) -> bytes:
    """Get information about the current session."""
    return chitose.xrpc.call('com.atproto.server.getSession', [], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.embed.external
import chitose.app.bsky.embed.images
import chitose.app.bsky.embed.record
import chitose.app.bsky.embed.record_with_media
import chitose.app.bsky.feed.post
import chitose.app.bsky.richtext.facet
import chitose.com.atproto.repo.strong_ref
import typing

class Post(chitose.Record):
    """


    :param entities: Deprecated: replaced by app.bsky.richtext.facet.
    """

    def __init__(self, text: str, created_at: str, entities: typing.Optional[list[chitose.app.bsky.feed.post.Entity]]=None, facets: typing.Optional[list[chitose.app.bsky.richtext.facet.Facet]]=None, reply: typing.Optional[chitose.app.bsky.feed.post.ReplyRef]=None, embed: typing.Optional[typing.Union[chitose.app.bsky.embed.images.Images, chitose.app.bsky.embed.external.External, chitose.app.bsky.embed.record.Record, chitose.app.bsky.embed.record_with_media.RecordWithMedia]]=None) -> None:
        self.text = text
        self.created_at = created_at
        self.entities = entities
        self.facets = facets
        self.reply = reply
        self.embed = embed

    def to_dict(self) -> dict:
        return {'text': self.text, 'createdAt': self.created_at, 'entities': self.entities, 'facets': self.facets, 'reply': self.reply, 'embed': self.embed, '$type': 'app.bsky.feed.post'}

class ReplyRef(chitose.Object):
    """"""

    def __init__(self, root: chitose.com.atproto.repo.strong_ref.StrongRef, parent: chitose.com.atproto.repo.strong_ref.StrongRef) -> None:
        self.root = root
        self.parent = parent

    def to_dict(self) -> dict:
        return {'root': self.root, 'parent': self.parent, '$type': 'app.bsky.feed.post#replyRef'}

class Entity(chitose.Object):
    """


    :param type: Expected values are 'mention' and 'link'.
    """

    def __init__(self, index: chitose.app.bsky.feed.post.TextSlice, type: str, value: str) -> None:
        self.index = index
        self.type = type
        self.value = value

    def to_dict(self) -> dict:
        return {'index': self.index, 'type': self.type, 'value': self.value, '$type': 'app.bsky.feed.post#entity'}

class TextSlice(chitose.Object):
    """"""

    def __init__(self, start: int, end: int) -> None:
        self.start = start
        self.end = end

    def to_dict(self) -> dict:
        return {'start': self.start, 'end': self.end, '$type': 'app.bsky.feed.post#textSlice'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import typing

def _get_likes(service: str, headers: dict[str, str], uri: str, cid: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.feed.getLikes', [('uri', uri), ('cid', cid), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)

class Like(chitose.Object):
    """"""

    def __init__(self, indexed_at: str, created_at: str, actor: chitose.app.bsky.actor.defs.ProfileView) -> None:
        self.indexed_at = indexed_at
        self.created_at = created_at
        self.actor = actor

    def to_dict(self) -> dict:
        return {'indexedAt': self.indexed_at, 'createdAt': self.created_at, 'actor': self.actor, '$type': 'app.bsky.feed.getLikes#like'}


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .get_unread_count import _get_unread_count
from .list_notifications import _list_notifications
from .update_seen import _update_seen
import chitose.app.bsky.actor.defs
import chitose.com.atproto.label.defs
import typing

class Notification_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def update_seen(self, seen_at: str) -> bytes:
        """Notify server that the user has seen notifications."""
        return _update_seen(self.service, self.headers, seen_at)

    def list_notifications(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None, seen_at: typing.Optional[str]=None) -> bytes:
        """"""
        return _list_notifications(self.service, self.headers, limit, cursor, seen_at)

    def get_unread_count(self, seen_at: typing.Optional[str]=None) -> bytes:
        """"""
        return _get_unread_count(self.service, self.headers, seen_at)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_lists(service: str, headers: dict[str, str], actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Fetch a list of lists that belong to an actor"""
    return chitose.xrpc.call('app.bsky.graph.getLists', [('actor', actor), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _create_session(service: str, headers: dict[str, str], identifier: str, password: str) -> bytes:
    """Create an authentication session.


    :param identifier: Handle or other identifier supported by the server for the authenticating user.
    """
    return chitose.xrpc.call('com.atproto.server.createSession', [], {'identifier': identifier, 'password': password}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _list_repos(service: str, headers: dict[str, str], limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """List dids and root cids of hosted repos"""
    return chitose.xrpc.call('com.atproto.sync.listRepos', [('limit', limit), ('cursor', cursor)], None, service, {} | headers)

class Repo(chitose.Object):
    """"""

    def __init__(self, did: str, head: str) -> None:
        self.did = did
        self.head = head

    def to_dict(self) -> dict:
        return {'did': self.did, 'head': self.head, '$type': 'com.atproto.sync.listRepos#repo'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.richtext.facet
import typing

class Generator(chitose.Record):
    """"""

    def __init__(self, did: str, display_name: str, created_at: str, description: typing.Optional[str]=None, description_facets: typing.Optional[list[chitose.app.bsky.richtext.facet.Facet]]=None, avatar: typing.Optional[chitose.Blob]=None) -> None:
        self.did = did
        self.display_name = display_name
        self.created_at = created_at
        self.description = description
        self.description_facets = description_facets
        self.avatar = avatar

    def to_dict(self) -> dict:
        return {'did': self.did, 'displayName': self.display_name, 'createdAt': self.created_at, 'description': self.description, 'descriptionFacets': self.description_facets, 'avatar': self.avatar, '$type': 'app.bsky.feed.generator'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _rebase_repo(service: str, headers: dict[str, str], repo: str, swap_commit: typing.Optional[str]=None) -> bytes:
    """Simple rebase of repo that deletes history


    :param repo: The handle or DID of the repo.

    :param swap_commit: Compare and swap with the previous commit by cid.
    """
    return chitose.xrpc.call('com.atproto.repo.rebaseRepo', [], {'repo': repo, 'swapCommit': swap_commit}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _list_app_passwords(service: str, headers: dict[str, str]) -> bytes:
    """List all app-specific passwords."""
    return chitose.xrpc.call('com.atproto.server.listAppPasswords', [], None, service, {} | headers)

class AppPassword(chitose.Object):
    """"""

    def __init__(self, name: str, created_at: str) -> None:
        self.name = name
        self.created_at = created_at

    def to_dict(self) -> dict:
        return {'name': self.name, 'createdAt': self.created_at, '$type': 'com.atproto.server.listAppPasswords#appPassword'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_blocks(service: str, headers: dict[str, str], limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Who is the requester's account blocking?"""
    return chitose.xrpc.call('app.bsky.graph.getBlocks', [('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .apply_writes import _apply_writes
from .create_record import _create_record
from .delete_record import _delete_record
from .describe_repo import _describe_repo
from .get_record import _get_record
from .list_records import _list_records
from .put_record import _put_record
from .rebase_repo import _rebase_repo
from .upload_blob import _upload_blob
import chitose.com.atproto.repo.apply_writes
import typing

class Repo_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def create_record(self, repo: str, collection: str, record: typing.Any, rkey: typing.Optional[str]=None, validate: typing.Optional[bool]=None, swap_commit: typing.Optional[str]=None) -> bytes:
        """Create a new record.


        :param repo: The handle or DID of the repo.

        :param collection: The NSID of the record collection.

        :param record: The record to create.

        :param rkey: The key of the record.

        :param validate: Validate the record?

        :param swap_commit: Compare and swap with the previous commit by cid.
        """
        return _create_record(self.service, self.headers, repo, collection, record, rkey, validate, swap_commit)

    def delete_record(self, repo: str, collection: str, rkey: str, swap_record: typing.Optional[str]=None, swap_commit: typing.Optional[str]=None) -> bytes:
        """Delete a record, or ensure it doesn't exist.


        :param repo: The handle or DID of the repo.

        :param collection: The NSID of the record collection.

        :param rkey: The key of the record.

        :param swap_record: Compare and swap with the previous record by cid.

        :param swap_commit: Compare and swap with the previous commit by cid.
        """
        return _delete_record(self.service, self.headers, repo, collection, rkey, swap_record, swap_commit)

    def put_record(self, repo: str, collection: str, rkey: str, record: typing.Any, validate: typing.Optional[bool]=None, swap_record: typing.Optional[str]=None, swap_commit: typing.Optional[str]=None) -> bytes:
        """Write a record, creating or updating it as needed.


        :param repo: The handle or DID of the repo.

        :param collection: The NSID of the record collection.

        :param rkey: The key of the record.

        :param record: The record to write.

        :param validate: Validate the record?

        :param swap_record: Compare and swap with the previous record by cid.

        :param swap_commit: Compare and swap with the previous commit by cid.
        """
        return _put_record(self.service, self.headers, repo, collection, rkey, record, validate, swap_record, swap_commit)

    def rebase_repo(self, repo: str, swap_commit: typing.Optional[str]=None) -> bytes:
        """Simple rebase of repo that deletes history


        :param repo: The handle or DID of the repo.

        :param swap_commit: Compare and swap with the previous commit by cid.
        """
        return _rebase_repo(self.service, self.headers, repo, swap_commit)

    def upload_blob(self, input_: bytes) -> bytes:
        """Upload a new blob to be added to repo in a later request."""
        return _upload_blob(self.service, self.headers, input_)

    def describe_repo(self, repo: str) -> bytes:
        """Get information about the repo, including the list of collections.


        :param repo: The handle or DID of the repo.
        """
        return _describe_repo(self.service, self.headers, repo)

    def get_record(self, repo: str, collection: str, rkey: str, cid: typing.Optional[str]=None) -> bytes:
        """Get a record.


        :param repo: The handle or DID of the repo.

        :param collection: The NSID of the record collection.

        :param rkey: The key of the record.

        :param cid: The CID of the version of the record. If not specified, then return the most recent version.
        """
        return _get_record(self.service, self.headers, repo, collection, rkey, cid)

    def apply_writes(self, repo: str, writes: list[typing.Union[chitose.com.atproto.repo.apply_writes.Create, chitose.com.atproto.repo.apply_writes.Update, chitose.com.atproto.repo.apply_writes.Delete]], validate: typing.Optional[bool]=None, swap_commit: typing.Optional[str]=None) -> bytes:
        """Apply a batch transaction of creates, updates, and deletes.


        :param repo: The handle or DID of the repo.

        :param validate: Validate the records?
        """
        return _apply_writes(self.service, self.headers, repo, writes, validate, swap_commit)

    def list_records(self, repo: str, collection: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None, rkey_start: typing.Optional[str]=None, rkey_end: typing.Optional[str]=None, reverse: typing.Optional[bool]=None) -> bytes:
        """List a range of records in a collection.


        :param repo: The handle or DID of the repo.

        :param collection: The NSID of the record type.

        :param limit: The number of records to return.

        :param rkey_start: DEPRECATED: The lowest sort-ordered rkey to start from (exclusive)

        :param rkey_end: DEPRECATED: The highest sort-ordered rkey to stop at (exclusive)

        :param reverse: Reverse the order of the returned records?
        """
        return _list_records(self.service, self.headers, repo, collection, limit, cursor, rkey_start, rkey_end, reverse)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.admin.defs
import chitose.com.atproto.moderation.defs
import chitose.com.atproto.repo.strong_ref
import typing

def _create_report(service: str, headers: dict[str, str], reason_type: chitose.com.atproto.moderation.defs.ReasonType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], reason: typing.Optional[str]=None) -> bytes:
    """Report a repo or a record."""
    return chitose.xrpc.call('com.atproto.moderation.createReport', [], {'reasonType': reason_type, 'reason': reason, 'subject': subject}, service, {'Content-Type': 'application/json'} | headers)


from .link import Link
from .blob import Blob
from .object import Object
from .record import Record
from .xrpc import call
from .agent import BskyAgent

__all__ = ['BskyAgent', 'Blob', 'Link', 'Object', 'Record', 'call']



# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _query_labels(service: str, headers: dict[str, str], uri_patterns: list[str], sources: typing.Optional[list[str]]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Find labels relevant to the provided URI patterns.


    :param uri_patterns: List of AT URI patterns to match (boolean 'OR'). Each may be a prefix (ending with '*'; will match inclusive of the string leading to '*'), or a full URI

    :param sources: Optional list of label sources (DIDs) to filter on
    """
    return chitose.xrpc.call('com.atproto.label.queryLabels', [('uriPatterns', uri_patterns), ('sources', sources), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.repo.strong_ref

class Repost(chitose.Record):
    """"""

    def __init__(self, subject: chitose.com.atproto.repo.strong_ref.StrongRef, created_at: str) -> None:
        self.subject = subject
        self.created_at = created_at

    def to_dict(self) -> dict:
        return {'subject': self.subject, 'createdAt': self.created_at, '$type': 'app.bsky.feed.repost'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _search_repos(service: str, headers: dict[str, str], term: typing.Optional[str]=None, invited_by: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Find repositories based on a search term."""
    return chitose.xrpc.call('com.atproto.admin.searchRepos', [('term', term), ('invitedBy', invited_by), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_blocks(service: str, headers: dict[str, str], did: str, cids: list[str]) -> bytes:
    """Gets blocks from a given repo.


    :param did: The DID of the repo.
    """
    return chitose.xrpc.call('com.atproto.sync.getBlocks', [('did', did), ('cids', cids)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_feed_generator(service: str, headers: dict[str, str], feed: str) -> bytes:
    """Get information about a specific feed offered by a feed generator, such as its online status"""
    return chitose.xrpc.call('app.bsky.feed.getFeedGenerator', [('feed', feed)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .disable_account_invites import _disable_account_invites
from .disable_invite_codes import _disable_invite_codes
from .enable_account_invites import _enable_account_invites
from .get_invite_codes import _get_invite_codes
from .get_moderation_action import _get_moderation_action
from .get_moderation_actions import _get_moderation_actions
from .get_moderation_report import _get_moderation_report
from .get_moderation_reports import _get_moderation_reports
from .get_record import _get_record
from .get_repo import _get_repo
from .resolve_moderation_reports import _resolve_moderation_reports
from .reverse_moderation_action import _reverse_moderation_action
from .search_repos import _search_repos
from .take_moderation_action import _take_moderation_action
from .update_account_email import _update_account_email
from .update_account_handle import _update_account_handle
import chitose.com.atproto.admin.defs
import chitose.com.atproto.repo.strong_ref
import typing

class Admin_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def get_repo(self, did: str) -> bytes:
        """View details about a repository."""
        return _get_repo(self.service, self.headers, did)

    def get_moderation_reports(self, subject: typing.Optional[str]=None, resolved: typing.Optional[bool]=None, action_type: typing.Optional[typing.Literal['com.atproto.admin.defs#takedown', 'com.atproto.admin.defs#flag', 'com.atproto.admin.defs#acknowledge', 'com.atproto.admin.defs#escalate']]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """List moderation reports related to a subject."""
        return _get_moderation_reports(self.service, self.headers, subject, resolved, action_type, limit, cursor)

    def take_moderation_action(self, action: typing.Literal['com.atproto.admin.defs#takedown', 'com.atproto.admin.defs#flag', 'com.atproto.admin.defs#acknowledge'], subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], reason: str, created_by: str, subject_blob_cids: typing.Optional[list[str]]=None, create_label_vals: typing.Optional[list[str]]=None, negate_label_vals: typing.Optional[list[str]]=None) -> bytes:
        """Take a moderation action on a repo."""
        return _take_moderation_action(self.service, self.headers, action, subject, reason, created_by, subject_blob_cids, create_label_vals, negate_label_vals)

    def update_account_email(self, account: str, email: str) -> bytes:
        """Administrative action to update an account's email


        :param account: The handle or DID of the repo.
        """
        return _update_account_email(self.service, self.headers, account, email)

    def get_moderation_action(self, id: int) -> bytes:
        """View details about a moderation action."""
        return _get_moderation_action(self.service, self.headers, id)

    def update_account_handle(self, did: str, handle: str) -> bytes:
        """Administrative action to update an account's handle"""
        return _update_account_handle(self.service, self.headers, did, handle)

    def get_invite_codes(self, sort: typing.Optional[typing.Literal['recent', 'usage']]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Admin view of invite codes"""
        return _get_invite_codes(self.service, self.headers, sort, limit, cursor)

    def enable_account_invites(self, account: str) -> bytes:
        """Re-enable an accounts ability to receive invite codes"""
        return _enable_account_invites(self.service, self.headers, account)

    def get_moderation_report(self, id: int) -> bytes:
        """View details about a moderation report."""
        return _get_moderation_report(self.service, self.headers, id)

    def disable_account_invites(self, account: str) -> bytes:
        """Disable an account from receiving new invite codes, but does not invalidate existing codes"""
        return _disable_account_invites(self.service, self.headers, account)

    def disable_invite_codes(self, codes: typing.Optional[list[str]]=None, accounts: typing.Optional[list[str]]=None) -> bytes:
        """Disable some set of codes and/or all codes associated with a set of users"""
        return _disable_invite_codes(self.service, self.headers, codes, accounts)

    def reverse_moderation_action(self, id: int, reason: str, created_by: str) -> bytes:
        """Reverse a moderation action."""
        return _reverse_moderation_action(self.service, self.headers, id, reason, created_by)

    def get_record(self, uri: str, cid: typing.Optional[str]=None) -> bytes:
        """View details about a record."""
        return _get_record(self.service, self.headers, uri, cid)

    def resolve_moderation_reports(self, action_id: int, report_ids: list[int], created_by: str) -> bytes:
        """Resolve moderation reports by an action."""
        return _resolve_moderation_reports(self.service, self.headers, action_id, report_ids, created_by)

    def search_repos(self, term: typing.Optional[str]=None, invited_by: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Find repositories based on a search term."""
        return _search_repos(self.service, self.headers, term, invited_by, limit, cursor)

    def get_moderation_actions(self, subject: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """List moderation actions related to a subject."""
        return _get_moderation_actions(self.service, self.headers, subject, limit, cursor)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _resolve_moderation_reports(service: str, headers: dict[str, str], action_id: int, report_ids: list[int], created_by: str) -> bytes:
    """Resolve moderation reports by an action."""
    return chitose.xrpc.call('com.atproto.admin.resolveModerationReports', [], {'actionId': action_id, 'reportIds': report_ids, 'createdBy': created_by}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _upload_blob(service: str, headers: dict[str, str], input_: bytes) -> bytes:
    """Upload a new blob to be added to repo in a later request."""
    return chitose.xrpc.call('com.atproto.repo.uploadBlob', [], input_, service, {'Content-Type': '*/*'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs
import chitose.app.bsky.graph.defs
import chitose.app.bsky.richtext.facet
import typing

class ListViewBasic(chitose.Object):
    """"""

    def __init__(self, uri: str, name: str, purpose: chitose.app.bsky.graph.defs.ListPurpose, avatar: typing.Optional[str], viewer: typing.Optional[chitose.app.bsky.graph.defs.ListViewerState]=None, indexed_at: typing.Optional[str]=None) -> None:
        self.uri = uri
        self.name = name
        self.purpose = purpose
        self.avatar = avatar
        self.viewer = viewer
        self.indexed_at = indexed_at

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'name': self.name, 'purpose': self.purpose, 'avatar': self.avatar, 'viewer': self.viewer, 'indexedAt': self.indexed_at, '$type': 'app.bsky.graph.defs#listViewBasic'}

class ListView(chitose.Object):
    """"""

    def __init__(self, uri: str, creator: chitose.app.bsky.actor.defs.ProfileView, name: str, purpose: chitose.app.bsky.graph.defs.ListPurpose, indexed_at: str, description: typing.Optional[str]=None, description_facets: typing.Optional[list[chitose.app.bsky.richtext.facet.Facet]]=None, avatar: typing.Optional[str]=None, viewer: typing.Optional[chitose.app.bsky.graph.defs.ListViewerState]=None) -> None:
        self.uri = uri
        self.creator = creator
        self.name = name
        self.purpose = purpose
        self.indexed_at = indexed_at
        self.description = description
        self.description_facets = description_facets
        self.avatar = avatar
        self.viewer = viewer

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'creator': self.creator, 'name': self.name, 'purpose': self.purpose, 'indexedAt': self.indexed_at, 'description': self.description, 'descriptionFacets': self.description_facets, 'avatar': self.avatar, 'viewer': self.viewer, '$type': 'app.bsky.graph.defs#listView'}

class ListItemView(chitose.Object):
    """"""

    def __init__(self, subject: chitose.app.bsky.actor.defs.ProfileView) -> None:
        self.subject = subject

    def to_dict(self) -> dict:
        return {'subject': self.subject, '$type': 'app.bsky.graph.defs#listItemView'}
ListPurpose = typing.Literal['app.bsky.graph.defs#modlist',]
MODLIST = 'app.bsky.graph.defs#modlist'

class ListViewerState(chitose.Object):
    """"""

    def __init__(self, muted: typing.Optional[bool]=None) -> None:
        self.muted = muted

    def to_dict(self) -> dict:
        return {'muted': self.muted, '$type': 'app.bsky.graph.defs#listViewerState'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_reposted_by(service: str, headers: dict[str, str], uri: str, cid: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """"""
    return chitose.xrpc.call('app.bsky.feed.getRepostedBy', [('uri', uri), ('cid', cid), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _update_seen(service: str, headers: dict[str, str], seen_at: str) -> bytes:
    """Notify server that the user has seen notifications."""
    return chitose.xrpc.call('app.bsky.notification.updateSeen', [], {'seenAt': seen_at}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

class Profile(chitose.Record):
    """"""

    def __init__(self, display_name: typing.Optional[str]=None, description: typing.Optional[str]=None, avatar: typing.Optional[chitose.Blob]=None, banner: typing.Optional[chitose.Blob]=None) -> None:
        self.display_name = display_name
        self.description = description
        self.avatar = avatar
        self.banner = banner

    def to_dict(self) -> dict:
        return {'displayName': self.display_name, 'description': self.description, 'avatar': self.avatar, 'banner': self.banner, '$type': 'app.bsky.actor.profile'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import typing
ReasonType = typing.Literal['com.atproto.moderation.defs#reasonSpam', 'com.atproto.moderation.defs#reasonViolation', 'com.atproto.moderation.defs#reasonMisleading', 'com.atproto.moderation.defs#reasonSexual', 'com.atproto.moderation.defs#reasonRude', 'com.atproto.moderation.defs#reasonOther']
REASON_SPAM = 'com.atproto.moderation.defs#reasonSpam'
REASON_VIOLATION = 'com.atproto.moderation.defs#reasonViolation'
REASON_MISLEADING = 'com.atproto.moderation.defs#reasonMisleading'
REASON_SEXUAL = 'com.atproto.moderation.defs#reasonSexual'
REASON_RUDE = 'com.atproto.moderation.defs#reasonRude'
REASON_OTHER = 'com.atproto.moderation.defs#reasonOther'


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.richtext.facet
import typing

class Facet(chitose.Object):
    """"""

    def __init__(self, index: chitose.app.bsky.richtext.facet.ByteSlice, features: list[typing.Union[chitose.app.bsky.richtext.facet.Mention, chitose.app.bsky.richtext.facet.Link]]) -> None:
        self.index = index
        self.features = features

    def to_dict(self) -> dict:
        return {'index': self.index, 'features': self.features, '$type': 'app.bsky.richtext.facet'}

class Mention(chitose.Object):
    """"""

    def __init__(self, did: str) -> None:
        self.did = did

    def to_dict(self) -> dict:
        return {'did': self.did, '$type': 'app.bsky.richtext.facet#mention'}

class Link(chitose.Object):
    """"""

    def __init__(self, uri: str) -> None:
        self.uri = uri

    def to_dict(self) -> dict:
        return {'uri': self.uri, '$type': 'app.bsky.richtext.facet#link'}

class ByteSlice(chitose.Object):
    """"""

    def __init__(self, byte_start: int, byte_end: int) -> None:
        self.byte_start = byte_start
        self.byte_end = byte_end

    def to_dict(self) -> dict:
        return {'byteStart': self.byte_start, 'byteEnd': self.byte_end, '$type': 'app.bsky.richtext.facet#byteSlice'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_commit_path(service: str, headers: dict[str, str], did: str, latest: typing.Optional[str]=None, earliest: typing.Optional[str]=None) -> bytes:
    """Gets the path of repo commits


    :param did: The DID of the repo.

    :param latest: The most recent commit

    :param earliest: The earliest commit to start from
    """
    return chitose.xrpc.call('com.atproto.sync.getCommitPath', [('did', did), ('latest', latest), ('earliest', earliest)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _create_invite_code(service: str, headers: dict[str, str], use_count: int, for_account: typing.Optional[str]=None) -> bytes:
    """Create an invite code."""
    return chitose.xrpc.call('com.atproto.server.createInviteCode', [], {'useCount': use_count, 'forAccount': for_account}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_posts(service: str, headers: dict[str, str], uris: list[str]) -> bytes:
    """A view of an actor's feed."""
    return chitose.xrpc.call('app.bsky.feed.getPosts', [('uris', uris)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _put_record(service: str, headers: dict[str, str], repo: str, collection: str, rkey: str, record: typing.Any, validate: typing.Optional[bool]=None, swap_record: typing.Optional[str]=None, swap_commit: typing.Optional[str]=None) -> bytes:
    """Write a record, creating or updating it as needed.


    :param repo: The handle or DID of the repo.

    :param collection: The NSID of the record collection.

    :param rkey: The key of the record.

    :param record: The record to write.

    :param validate: Validate the record?

    :param swap_record: Compare and swap with the previous record by cid.

    :param swap_commit: Compare and swap with the previous commit by cid.
    """
    return chitose.xrpc.call('com.atproto.repo.putRecord', [], {'repo': repo, 'collection': collection, 'rkey': rkey, 'validate': validate, 'record': record, 'swapRecord': swap_record, 'swapCommit': swap_commit}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _request_crawl(service: str, headers: dict[str, str], hostname: str) -> bytes:
    """Request a service to persistently crawl hosted repos.


    :param hostname: Hostname of the service that is requesting to be crawled.
    """
    return chitose.xrpc.call('com.atproto.sync.requestCrawl', [('hostname', hostname)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_preferences(service: str, headers: dict[str, str]) -> bytes:
    """Get private preferences attached to the account."""
    return chitose.xrpc.call('app.bsky.actor.getPreferences', [], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _describe_repo(service: str, headers: dict[str, str], repo: str) -> bytes:
    """Get information about the repo, including the list of collections.


    :param repo: The handle or DID of the repo.
    """
    return chitose.xrpc.call('com.atproto.repo.describeRepo', [('repo', repo)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _create_invite_codes(service: str, headers: dict[str, str], code_count: int, use_count: int, for_accounts: typing.Optional[list[str]]=None) -> bytes:
    """Create an invite code."""
    return chitose.xrpc.call('com.atproto.server.createInviteCodes', [], {'codeCount': code_count, 'useCount': use_count, 'forAccounts': for_accounts}, service, {'Content-Type': 'application/json'} | headers)

class AccountCodes(chitose.Object):
    """"""

    def __init__(self, account: str, codes: list[str]) -> None:
        self.account = account
        self.codes = codes

    def to_dict(self) -> dict:
        return {'account': self.account, 'codes': self.codes, '$type': 'com.atproto.server.createInviteCodes#accountCodes'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _describe_feed_generator(service: str, headers: dict[str, str]) -> bytes:
    """Returns information about a given feed generator including TOS & offered feed URIs"""
    return chitose.xrpc.call('app.bsky.feed.describeFeedGenerator', [], None, service, {} | headers)

class Feed(chitose.Object):
    """"""

    def __init__(self, uri: str) -> None:
        self.uri = uri

    def to_dict(self) -> dict:
        return {'uri': self.uri, '$type': 'app.bsky.feed.describeFeedGenerator#feed'}

class Links(chitose.Object):
    """"""

    def __init__(self, privacy_policy: typing.Optional[str]=None, terms_of_service: typing.Optional[str]=None) -> None:
        self.privacy_policy = privacy_policy
        self.terms_of_service = terms_of_service

    def to_dict(self) -> dict:
        return {'privacyPolicy': self.privacy_policy, 'termsOfService': self.terms_of_service, '$type': 'app.bsky.feed.describeFeedGenerator#links'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _get_head(service: str, headers: dict[str, str], did: str) -> bytes:
    """Gets the current HEAD CID of a repo.


    :param did: The DID of the repo.
    """
    return chitose.xrpc.call('com.atproto.sync.getHead', [('did', did)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.app.bsky.actor.defs

def _put_preferences(service: str, headers: dict[str, str], preferences: chitose.app.bsky.actor.defs.Preferences) -> bytes:
    """Sets the private preferences attached to the account."""
    return chitose.xrpc.call('app.bsky.actor.putPreferences', [], {'preferences': preferences}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
"""A representation of a record embedded in another form of content, alongside other compatible embeds"""
from __future__ import annotations
import chitose
import chitose.app.bsky.embed.external
import chitose.app.bsky.embed.images
import chitose.app.bsky.embed.record
import typing

class RecordWithMedia(chitose.Object):
    """"""

    def __init__(self, record: chitose.app.bsky.embed.record.Record, media: typing.Union[chitose.app.bsky.embed.images.Images, chitose.app.bsky.embed.external.External]) -> None:
        self.record = record
        self.media = media

    def to_dict(self) -> dict:
        return {'record': self.record, 'media': self.media, '$type': 'app.bsky.embed.recordWithMedia'}

class View(chitose.Object):
    """"""

    def __init__(self, record: chitose.app.bsky.embed.record.View, media: typing.Union[chitose.app.bsky.embed.images.View, chitose.app.bsky.embed.external.View]) -> None:
        self.record = record
        self.media = media

    def to_dict(self) -> dict:
        return {'record': self.record, 'media': self.media, '$type': 'app.bsky.embed.recordWithMedia#view'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _delete_account(service: str, headers: dict[str, str], did: str, password: str, token: str) -> bytes:
    """Delete a user account with a token and password."""
    return chitose.xrpc.call('com.atproto.server.deleteAccount', [], {'did': did, 'password': password, 'token': token}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_checkout(service: str, headers: dict[str, str], did: str, commit: typing.Optional[str]=None) -> bytes:
    """Gets the repo state.


    :param did: The DID of the repo.

    :param commit: The commit to get the checkout from. Defaults to current HEAD.
    """
    return chitose.xrpc.call('com.atproto.sync.getCheckout', [('did', did), ('commit', commit)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _revoke_app_password(service: str, headers: dict[str, str], name: str) -> bytes:
    """Revoke an app-specific password by name."""
    return chitose.xrpc.call('com.atproto.server.revokeAppPassword', [], {'name': name}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .get_blob import _get_blob
from .get_blocks import _get_blocks
from .get_checkout import _get_checkout
from .get_commit_path import _get_commit_path
from .get_head import _get_head
from .get_record import _get_record
from .get_repo import _get_repo
from .list_blobs import _list_blobs
from .list_repos import _list_repos
from .notify_of_update import _notify_of_update
from .request_crawl import _request_crawl
import typing

class Sync_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def get_head(self, did: str) -> bytes:
        """Gets the current HEAD CID of a repo.


        :param did: The DID of the repo.
        """
        return _get_head(self.service, self.headers, did)

    def get_blob(self, did: str, cid: str) -> bytes:
        """Get a blob associated with a given repo.


        :param did: The DID of the repo.

        :param cid: The CID of the blob to fetch
        """
        return _get_blob(self.service, self.headers, did, cid)

    def get_repo(self, did: str, earliest: typing.Optional[str]=None, latest: typing.Optional[str]=None) -> bytes:
        """Gets the repo state.


        :param did: The DID of the repo.

        :param earliest: The earliest commit in the commit range (not inclusive)

        :param latest: The latest commit in the commit range (inclusive)
        """
        return _get_repo(self.service, self.headers, did, earliest, latest)

    def notify_of_update(self, hostname: str) -> bytes:
        """Notify a crawling service of a recent update. Often when a long break between updates causes the connection with the crawling service to break.


        :param hostname: Hostname of the service that is notifying of update.
        """
        return _notify_of_update(self.service, self.headers, hostname)

    def request_crawl(self, hostname: str) -> bytes:
        """Request a service to persistently crawl hosted repos.


        :param hostname: Hostname of the service that is requesting to be crawled.
        """
        return _request_crawl(self.service, self.headers, hostname)

    def list_blobs(self, did: str, latest: typing.Optional[str]=None, earliest: typing.Optional[str]=None) -> bytes:
        """List blob cids for some range of commits


        :param did: The DID of the repo.

        :param latest: The most recent commit

        :param earliest: The earliest commit to start from
        """
        return _list_blobs(self.service, self.headers, did, latest, earliest)

    def get_record(self, did: str, collection: str, rkey: str, commit: typing.Optional[str]=None) -> bytes:
        """Gets blocks needed for existence or non-existence of record.


        :param did: The DID of the repo.

        :param commit: An optional past commit CID.
        """
        return _get_record(self.service, self.headers, did, collection, rkey, commit)

    def list_repos(self, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """List dids and root cids of hosted repos"""
        return _list_repos(self.service, self.headers, limit, cursor)

    def get_commit_path(self, did: str, latest: typing.Optional[str]=None, earliest: typing.Optional[str]=None) -> bytes:
        """Gets the path of repo commits


        :param did: The DID of the repo.

        :param latest: The most recent commit

        :param earliest: The earliest commit to start from
        """
        return _get_commit_path(self.service, self.headers, did, latest, earliest)

    def get_blocks(self, did: str, cids: list[str]) -> bytes:
        """Gets blocks from a given repo.


        :param did: The DID of the repo.
        """
        return _get_blocks(self.service, self.headers, did, cids)

    def get_checkout(self, did: str, commit: typing.Optional[str]=None) -> bytes:
        """Gets the repo state.


        :param did: The DID of the repo.

        :param commit: The commit to get the checkout from. Defaults to current HEAD.
        """
        return _get_checkout(self.service, self.headers, did, commit)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.repo.apply_writes
import typing

def _apply_writes(service: str, headers: dict[str, str], repo: str, writes: list[typing.Union[chitose.com.atproto.repo.apply_writes.Create, chitose.com.atproto.repo.apply_writes.Update, chitose.com.atproto.repo.apply_writes.Delete]], validate: typing.Optional[bool]=None, swap_commit: typing.Optional[str]=None) -> bytes:
    """Apply a batch transaction of creates, updates, and deletes.


    :param repo: The handle or DID of the repo.

    :param validate: Validate the records?
    """
    return chitose.xrpc.call('com.atproto.repo.applyWrites', [], {'repo': repo, 'validate': validate, 'writes': writes, 'swapCommit': swap_commit}, service, {'Content-Type': 'application/json'} | headers)

class Create(chitose.Object):
    """"""

    def __init__(self, collection: str, value: typing.Any, rkey: typing.Optional[str]) -> None:
        self.collection = collection
        self.value = value
        self.rkey = rkey

    def to_dict(self) -> dict:
        return {'collection': self.collection, 'value': self.value, 'rkey': self.rkey, '$type': 'com.atproto.repo.applyWrites#create'}

class Update(chitose.Object):
    """"""

    def __init__(self, collection: str, rkey: str, value: typing.Any) -> None:
        self.collection = collection
        self.rkey = rkey
        self.value = value

    def to_dict(self) -> dict:
        return {'collection': self.collection, 'rkey': self.rkey, 'value': self.value, '$type': 'com.atproto.repo.applyWrites#update'}

class Delete(chitose.Object):
    """"""

    def __init__(self, collection: str, rkey: str) -> None:
        self.collection = collection
        self.rkey = rkey

    def to_dict(self) -> dict:
        return {'collection': self.collection, 'rkey': self.rkey, '$type': 'com.atproto.repo.applyWrites#delete'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _disable_invite_codes(service: str, headers: dict[str, str], codes: typing.Optional[list[str]]=None, accounts: typing.Optional[list[str]]=None) -> bytes:
    """Disable some set of codes and/or all codes associated with a set of users"""
    return chitose.xrpc.call('com.atproto.admin.disableInviteCodes', [], {'codes': codes, 'accounts': accounts}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _search_actors(service: str, headers: dict[str, str], term: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """Find actors matching search criteria."""
    return chitose.xrpc.call('app.bsky.actor.searchActors', [('term', term), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
"""A set of images embedded in some other form of content"""
from __future__ import annotations
import chitose
import chitose.app.bsky.embed.images

class Images(chitose.Object):
    """"""

    def __init__(self, images: list[chitose.app.bsky.embed.images.Image]) -> None:
        self.images = images

    def to_dict(self) -> dict:
        return {'images': self.images, '$type': 'app.bsky.embed.images'}

class Image(chitose.Object):
    """"""

    def __init__(self, image: chitose.Blob, alt: str) -> None:
        self.image = image
        self.alt = alt

    def to_dict(self) -> dict:
        return {'image': self.image, 'alt': self.alt, '$type': 'app.bsky.embed.images#image'}

class View(chitose.Object):
    """"""

    def __init__(self, images: list[chitose.app.bsky.embed.images.ViewImage]) -> None:
        self.images = images

    def to_dict(self) -> dict:
        return {'images': self.images, '$type': 'app.bsky.embed.images#view'}

class ViewImage(chitose.Object):
    """"""

    def __init__(self, thumb: str, fullsize: str, alt: str) -> None:
        self.thumb = thumb
        self.fullsize = fullsize
        self.alt = alt

    def to_dict(self) -> dict:
        return {'thumb': self.thumb, 'fullsize': self.fullsize, 'alt': self.alt, '$type': 'app.bsky.embed.images#viewImage'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_moderation_actions(service: str, headers: dict[str, str], subject: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
    """List moderation actions related to a subject."""
    return chitose.xrpc.call('com.atproto.admin.getModerationActions', [('subject', subject), ('limit', limit), ('cursor', cursor)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _update_account_email(service: str, headers: dict[str, str], account: str, email: str) -> bytes:
    """Administrative action to update an account's email


    :param account: The handle or DID of the repo.
    """
    return chitose.xrpc.call('com.atproto.admin.updateAccountEmail', [], {'account': account, 'email': email}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
from __future__ import annotations
from .describe_feed_generator import _describe_feed_generator
from .get_actor_feeds import _get_actor_feeds
from .get_author_feed import _get_author_feed
from .get_feed import _get_feed
from .get_feed_generator import _get_feed_generator
from .get_feed_generators import _get_feed_generators
from .get_feed_skeleton import _get_feed_skeleton
from .get_likes import _get_likes
from .get_post_thread import _get_post_thread
from .get_posts import _get_posts
from .get_reposted_by import _get_reposted_by
from .get_timeline import _get_timeline
import chitose.app.bsky.actor.defs
import typing

class Feed_:
    """We recommend calling methods in this class via the :doc:`chitose.BskyAgent <chitose>` class instead of creating instances of this class directly."""

    def __init__(self, service: str, headers: dict[str, str]) -> None:
        self.service = service
        self.headers = headers

    def get_feed_generators(self, feeds: list[str]) -> bytes:
        """Get information about a list of feed generators"""
        return _get_feed_generators(self.service, self.headers, feeds)

    def get_timeline(self, algorithm: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """A view of the user's home timeline."""
        return _get_timeline(self.service, self.headers, algorithm, limit, cursor)

    def get_feed_generator(self, feed: str) -> bytes:
        """Get information about a specific feed offered by a feed generator, such as its online status"""
        return _get_feed_generator(self.service, self.headers, feed)

    def get_author_feed(self, actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """A view of an actor's feed."""
        return _get_author_feed(self.service, self.headers, actor, limit, cursor)

    def get_likes(self, uri: str, cid: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """"""
        return _get_likes(self.service, self.headers, uri, cid, limit, cursor)

    def get_post_thread(self, uri: str, depth: typing.Optional[int]=None) -> bytes:
        """"""
        return _get_post_thread(self.service, self.headers, uri, depth)

    def get_reposted_by(self, uri: str, cid: typing.Optional[str]=None, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """"""
        return _get_reposted_by(self.service, self.headers, uri, cid, limit, cursor)

    def describe_feed_generator(self) -> bytes:
        """Returns information about a given feed generator including TOS & offered feed URIs"""
        return _describe_feed_generator(self.service, self.headers)

    def get_posts(self, uris: list[str]) -> bytes:
        """A view of an actor's feed."""
        return _get_posts(self.service, self.headers, uris)

    def get_feed(self, feed: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Compose and hydrate a feed from a user's selected feed generator"""
        return _get_feed(self.service, self.headers, feed, limit, cursor)

    def get_feed_skeleton(self, feed: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """A skeleton of a feed provided by a feed generator"""
        return _get_feed_skeleton(self.service, self.headers, feed, limit, cursor)

    def get_actor_feeds(self, actor: str, limit: typing.Optional[int]=None, cursor: typing.Optional[str]=None) -> bytes:
        """Retrieve a list of feeds created by a given actor"""
        return _get_actor_feeds(self.service, self.headers, actor, limit, cursor)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _delete_session(service: str, headers: dict[str, str]) -> bytes:
    """Delete the current session."""
    return chitose.xrpc.call('com.atproto.server.deleteSession', [], {}, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _notify_of_update(service: str, headers: dict[str, str], hostname: str) -> bytes:
    """Notify a crawling service of a recent update. Often when a long break between updates causes the connection with the crawling service to break.


    :param hostname: Hostname of the service that is notifying of update.
    """
    return chitose.xrpc.call('com.atproto.sync.notifyOfUpdate', [('hostname', hostname)], None, service, {} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose

def _disable_account_invites(service: str, headers: dict[str, str], account: str) -> bytes:
    """Disable an account from receiving new invite codes, but does not invalidate existing codes"""
    return chitose.xrpc.call('com.atproto.admin.disableAccountInvites', [], {'account': account}, service, {'Content-Type': 'application/json'} | headers)


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import chitose.com.atproto.admin.defs
import chitose.com.atproto.label.defs
import chitose.com.atproto.moderation.defs
import chitose.com.atproto.repo.strong_ref
import chitose.com.atproto.server.defs
import typing

class ActionView(chitose.Object):
    """"""

    def __init__(self, id: int, action: chitose.com.atproto.admin.defs.ActionType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], subject_blob_cids: list[str], reason: str, created_by: str, created_at: str, resolved_report_ids: list[int], create_label_vals: typing.Optional[list[str]]=None, negate_label_vals: typing.Optional[list[str]]=None, reversal: typing.Optional[chitose.com.atproto.admin.defs.ActionReversal]=None) -> None:
        self.id = id
        self.action = action
        self.subject = subject
        self.subject_blob_cids = subject_blob_cids
        self.reason = reason
        self.created_by = created_by
        self.created_at = created_at
        self.resolved_report_ids = resolved_report_ids
        self.create_label_vals = create_label_vals
        self.negate_label_vals = negate_label_vals
        self.reversal = reversal

    def to_dict(self) -> dict:
        return {'id': self.id, 'action': self.action, 'subject': self.subject, 'subjectBlobCids': self.subject_blob_cids, 'reason': self.reason, 'createdBy': self.created_by, 'createdAt': self.created_at, 'resolvedReportIds': self.resolved_report_ids, 'createLabelVals': self.create_label_vals, 'negateLabelVals': self.negate_label_vals, 'reversal': self.reversal, '$type': 'com.atproto.admin.defs#actionView'}

class ActionViewDetail(chitose.Object):
    """"""

    def __init__(self, id: int, action: chitose.com.atproto.admin.defs.ActionType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoView, chitose.com.atproto.admin.defs.RepoViewNotFound, chitose.com.atproto.admin.defs.RecordView, chitose.com.atproto.admin.defs.RecordViewNotFound], subject_blobs: list[chitose.com.atproto.admin.defs.BlobView], reason: str, created_by: str, created_at: str, resolved_reports: list[chitose.com.atproto.admin.defs.ReportView], create_label_vals: typing.Optional[list[str]]=None, negate_label_vals: typing.Optional[list[str]]=None, reversal: typing.Optional[chitose.com.atproto.admin.defs.ActionReversal]=None) -> None:
        self.id = id
        self.action = action
        self.subject = subject
        self.subject_blobs = subject_blobs
        self.reason = reason
        self.created_by = created_by
        self.created_at = created_at
        self.resolved_reports = resolved_reports
        self.create_label_vals = create_label_vals
        self.negate_label_vals = negate_label_vals
        self.reversal = reversal

    def to_dict(self) -> dict:
        return {'id': self.id, 'action': self.action, 'subject': self.subject, 'subjectBlobs': self.subject_blobs, 'reason': self.reason, 'createdBy': self.created_by, 'createdAt': self.created_at, 'resolvedReports': self.resolved_reports, 'createLabelVals': self.create_label_vals, 'negateLabelVals': self.negate_label_vals, 'reversal': self.reversal, '$type': 'com.atproto.admin.defs#actionViewDetail'}

class ActionViewCurrent(chitose.Object):
    """"""

    def __init__(self, id: int, action: chitose.com.atproto.admin.defs.ActionType) -> None:
        self.id = id
        self.action = action

    def to_dict(self) -> dict:
        return {'id': self.id, 'action': self.action, '$type': 'com.atproto.admin.defs#actionViewCurrent'}

class ActionReversal(chitose.Object):
    """"""

    def __init__(self, reason: str, created_by: str, created_at: str) -> None:
        self.reason = reason
        self.created_by = created_by
        self.created_at = created_at

    def to_dict(self) -> dict:
        return {'reason': self.reason, 'createdBy': self.created_by, 'createdAt': self.created_at, '$type': 'com.atproto.admin.defs#actionReversal'}
ActionType = typing.Literal['#takedown', '#flag', '#acknowledge', '#escalate']
TAKEDOWN = 'com.atproto.admin.defs#takedown'
FLAG = 'com.atproto.admin.defs#flag'
ACKNOWLEDGE = 'com.atproto.admin.defs#acknowledge'
ESCALATE = 'com.atproto.admin.defs#escalate'

class ReportView(chitose.Object):
    """"""

    def __init__(self, id: int, reason_type: chitose.com.atproto.moderation.defs.ReasonType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoRef, chitose.com.atproto.repo.strong_ref.StrongRef], reported_by: str, created_at: str, resolved_by_action_ids: list[int], reason: typing.Optional[str]=None) -> None:
        self.id = id
        self.reason_type = reason_type
        self.subject = subject
        self.reported_by = reported_by
        self.created_at = created_at
        self.resolved_by_action_ids = resolved_by_action_ids
        self.reason = reason

    def to_dict(self) -> dict:
        return {'id': self.id, 'reasonType': self.reason_type, 'subject': self.subject, 'reportedBy': self.reported_by, 'createdAt': self.created_at, 'resolvedByActionIds': self.resolved_by_action_ids, 'reason': self.reason, '$type': 'com.atproto.admin.defs#reportView'}

class ReportViewDetail(chitose.Object):
    """"""

    def __init__(self, id: int, reason_type: chitose.com.atproto.moderation.defs.ReasonType, subject: typing.Union[chitose.com.atproto.admin.defs.RepoView, chitose.com.atproto.admin.defs.RepoViewNotFound, chitose.com.atproto.admin.defs.RecordView, chitose.com.atproto.admin.defs.RecordViewNotFound], reported_by: str, created_at: str, resolved_by_actions: list[chitose.com.atproto.admin.defs.ActionView], reason: typing.Optional[str]=None) -> None:
        self.id = id
        self.reason_type = reason_type
        self.subject = subject
        self.reported_by = reported_by
        self.created_at = created_at
        self.resolved_by_actions = resolved_by_actions
        self.reason = reason

    def to_dict(self) -> dict:
        return {'id': self.id, 'reasonType': self.reason_type, 'subject': self.subject, 'reportedBy': self.reported_by, 'createdAt': self.created_at, 'resolvedByActions': self.resolved_by_actions, 'reason': self.reason, '$type': 'com.atproto.admin.defs#reportViewDetail'}

class RepoView(chitose.Object):
    """"""

    def __init__(self, did: str, handle: str, related_records: list[typing.Any], indexed_at: str, moderation: chitose.com.atproto.admin.defs.Moderation, email: typing.Optional[str]=None, invited_by: typing.Optional[chitose.com.atproto.server.defs.InviteCode]=None, invites_disabled: typing.Optional[bool]=None) -> None:
        self.did = did
        self.handle = handle
        self.related_records = related_records
        self.indexed_at = indexed_at
        self.moderation = moderation
        self.email = email
        self.invited_by = invited_by
        self.invites_disabled = invites_disabled

    def to_dict(self) -> dict:
        return {'did': self.did, 'handle': self.handle, 'relatedRecords': self.related_records, 'indexedAt': self.indexed_at, 'moderation': self.moderation, 'email': self.email, 'invitedBy': self.invited_by, 'invitesDisabled': self.invites_disabled, '$type': 'com.atproto.admin.defs#repoView'}

class RepoViewDetail(chitose.Object):
    """"""

    def __init__(self, did: str, handle: str, related_records: list[typing.Any], indexed_at: str, moderation: chitose.com.atproto.admin.defs.ModerationDetail, email: typing.Optional[str]=None, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None, invited_by: typing.Optional[chitose.com.atproto.server.defs.InviteCode]=None, invites: typing.Optional[list[chitose.com.atproto.server.defs.InviteCode]]=None, invites_disabled: typing.Optional[bool]=None) -> None:
        self.did = did
        self.handle = handle
        self.related_records = related_records
        self.indexed_at = indexed_at
        self.moderation = moderation
        self.email = email
        self.labels = labels
        self.invited_by = invited_by
        self.invites = invites
        self.invites_disabled = invites_disabled

    def to_dict(self) -> dict:
        return {'did': self.did, 'handle': self.handle, 'relatedRecords': self.related_records, 'indexedAt': self.indexed_at, 'moderation': self.moderation, 'email': self.email, 'labels': self.labels, 'invitedBy': self.invited_by, 'invites': self.invites, 'invitesDisabled': self.invites_disabled, '$type': 'com.atproto.admin.defs#repoViewDetail'}

class RepoViewNotFound(chitose.Object):
    """"""

    def __init__(self, did: str) -> None:
        self.did = did

    def to_dict(self) -> dict:
        return {'did': self.did, '$type': 'com.atproto.admin.defs#repoViewNotFound'}

class RepoRef(chitose.Object):
    """"""

    def __init__(self, did: str) -> None:
        self.did = did

    def to_dict(self) -> dict:
        return {'did': self.did, '$type': 'com.atproto.admin.defs#repoRef'}

class RecordView(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, value: typing.Any, blob_cids: list[str], indexed_at: str, moderation: chitose.com.atproto.admin.defs.Moderation, repo: chitose.com.atproto.admin.defs.RepoView) -> None:
        self.uri = uri
        self.cid = cid
        self.value = value
        self.blob_cids = blob_cids
        self.indexed_at = indexed_at
        self.moderation = moderation
        self.repo = repo

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'value': self.value, 'blobCids': self.blob_cids, 'indexedAt': self.indexed_at, 'moderation': self.moderation, 'repo': self.repo, '$type': 'com.atproto.admin.defs#recordView'}

class RecordViewDetail(chitose.Object):
    """"""

    def __init__(self, uri: str, cid: str, value: typing.Any, blobs: list[chitose.com.atproto.admin.defs.BlobView], indexed_at: str, moderation: chitose.com.atproto.admin.defs.ModerationDetail, repo: chitose.com.atproto.admin.defs.RepoView, labels: typing.Optional[list[chitose.com.atproto.label.defs.Label]]=None) -> None:
        self.uri = uri
        self.cid = cid
        self.value = value
        self.blobs = blobs
        self.indexed_at = indexed_at
        self.moderation = moderation
        self.repo = repo
        self.labels = labels

    def to_dict(self) -> dict:
        return {'uri': self.uri, 'cid': self.cid, 'value': self.value, 'blobs': self.blobs, 'indexedAt': self.indexed_at, 'moderation': self.moderation, 'repo': self.repo, 'labels': self.labels, '$type': 'com.atproto.admin.defs#recordViewDetail'}

class RecordViewNotFound(chitose.Object):
    """"""

    def __init__(self, uri: str) -> None:
        self.uri = uri

    def to_dict(self) -> dict:
        return {'uri': self.uri, '$type': 'com.atproto.admin.defs#recordViewNotFound'}

class Moderation(chitose.Object):
    """"""

    def __init__(self, current_action: typing.Optional[chitose.com.atproto.admin.defs.ActionViewCurrent]=None) -> None:
        self.current_action = current_action

    def to_dict(self) -> dict:
        return {'currentAction': self.current_action, '$type': 'com.atproto.admin.defs#moderation'}

class ModerationDetail(chitose.Object):
    """"""

    def __init__(self, actions: list[chitose.com.atproto.admin.defs.ActionView], reports: list[chitose.com.atproto.admin.defs.ReportView], current_action: typing.Optional[chitose.com.atproto.admin.defs.ActionViewCurrent]=None) -> None:
        self.actions = actions
        self.reports = reports
        self.current_action = current_action

    def to_dict(self) -> dict:
        return {'actions': self.actions, 'reports': self.reports, 'currentAction': self.current_action, '$type': 'com.atproto.admin.defs#moderationDetail'}

class BlobView(chitose.Object):
    """"""

    def __init__(self, cid: str, mime_type: str, size: int, created_at: str, details: typing.Optional[typing.Union[chitose.com.atproto.admin.defs.ImageDetails, chitose.com.atproto.admin.defs.VideoDetails]]=None, moderation: typing.Optional[chitose.com.atproto.admin.defs.Moderation]=None) -> None:
        self.cid = cid
        self.mime_type = mime_type
        self.size = size
        self.created_at = created_at
        self.details = details
        self.moderation = moderation

    def to_dict(self) -> dict:
        return {'cid': self.cid, 'mimeType': self.mime_type, 'size': self.size, 'createdAt': self.created_at, 'details': self.details, 'moderation': self.moderation, '$type': 'com.atproto.admin.defs#blobView'}

class ImageDetails(chitose.Object):
    """"""

    def __init__(self, width: int, height: int) -> None:
        self.width = width
        self.height = height

    def to_dict(self) -> dict:
        return {'width': self.width, 'height': self.height, '$type': 'com.atproto.admin.defs#imageDetails'}

class VideoDetails(chitose.Object):
    """"""

    def __init__(self, width: int, height: int, length: int) -> None:
        self.width = width
        self.height = height
        self.length = length

    def to_dict(self) -> dict:
        return {'width': self.width, 'height': self.height, 'length': self.length, '$type': 'com.atproto.admin.defs#videoDetails'}


# GENERATED CODE - DO NOT MODIFY
""""""
from __future__ import annotations
import chitose
import typing

def _get_account_invite_codes(service: str, headers: dict[str, str], include_used: typing.Optional[bool]=None, create_available: typing.Optional[bool]=None) -> bytes:
    """Get all invite codes for a given account"""
    return chitose.xrpc.call('com.atproto.server.getAccountInviteCodes', [('includeUsed', include_used), ('createAvailable', create_available)], None, service, {} | headers)